Class: Aws::GreengrassV2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::GreengrassV2::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-greengrassv2/client.rb,
sig/client.rbs
Overview
An API client for GreengrassV2. To construct a client, you need to configure a :region and :credentials.
client = Aws::GreengrassV2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateServiceRoleToAccountResponseSuccess, _BatchAssociateClientDeviceWithCoreDeviceResponseSuccess, _BatchDisassociateClientDeviceFromCoreDeviceResponseSuccess, _CancelDeploymentResponseSuccess, _CreateComponentVersionResponseSuccess, _CreateDeploymentResponseSuccess, _DescribeComponentResponseSuccess, _DisassociateServiceRoleFromAccountResponseSuccess, _GetComponentResponseSuccess, _GetComponentVersionArtifactResponseSuccess, _GetConnectivityInfoResponseSuccess, _GetCoreDeviceResponseSuccess, _GetDeploymentResponseSuccess, _GetServiceRoleForAccountResponseSuccess, _ListClientDevicesAssociatedWithCoreDeviceResponseSuccess, _ListComponentVersionsResponseSuccess, _ListComponentsResponseSuccess, _ListCoreDevicesResponseSuccess, _ListDeploymentsResponseSuccess, _ListEffectiveDeploymentsResponseSuccess, _ListInstalledComponentsResponseSuccess, _ListTagsForResourceResponseSuccess, _ResolveComponentCandidatesResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateConnectivityInfoResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_service_role_to_account(params = {}) ⇒ Types::AssociateServiceRoleToAccountResponse
Associates a Greengrass service role with IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region.
-
#batch_associate_client_device_with_core_device(params = {}) ⇒ Types::BatchAssociateClientDeviceWithCoreDeviceResponse
Associates a list of client devices with a core device.
-
#batch_disassociate_client_device_from_core_device(params = {}) ⇒ Types::BatchDisassociateClientDeviceFromCoreDeviceResponse
Disassociates a list of client devices from a core device.
-
#cancel_deployment(params = {}) ⇒ Types::CancelDeploymentResponse
Cancels a deployment.
-
#create_component_version(params = {}) ⇒ Types::CreateComponentVersionResponse
Creates a component.
-
#create_deployment(params = {}) ⇒ Types::CreateDeploymentResponse
Creates a continuous deployment for a target, which is a Greengrass core device or group of core devices.
-
#delete_component(params = {}) ⇒ Struct
Deletes a version of a component from IoT Greengrass.
-
#delete_core_device(params = {}) ⇒ Struct
Deletes a Greengrass core device, which is an IoT thing.
-
#delete_deployment(params = {}) ⇒ Struct
Deletes a deployment.
-
#describe_component(params = {}) ⇒ Types::DescribeComponentResponse
Retrieves metadata for a version of a component.
-
#disassociate_service_role_from_account(params = {}) ⇒ Types::DisassociateServiceRoleFromAccountResponse
Disassociates the Greengrass service role from IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region.
-
#get_component(params = {}) ⇒ Types::GetComponentResponse
Gets the recipe for a version of a component.
-
#get_component_version_artifact(params = {}) ⇒ Types::GetComponentVersionArtifactResponse
Gets the pre-signed URL to download a public or a Lambda component artifact.
-
#get_connectivity_info(params = {}) ⇒ Types::GetConnectivityInfoResponse
Retrieves connectivity information for a Greengrass core device.
-
#get_core_device(params = {}) ⇒ Types::GetCoreDeviceResponse
Retrieves metadata for a Greengrass core device.
-
#get_deployment(params = {}) ⇒ Types::GetDeploymentResponse
Gets a deployment.
-
#get_service_role_for_account(params = {}) ⇒ Types::GetServiceRoleForAccountResponse
Gets the service role associated with IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region.
-
#list_client_devices_associated_with_core_device(params = {}) ⇒ Types::ListClientDevicesAssociatedWithCoreDeviceResponse
Retrieves a paginated list of client devices that are associated with a core device.
-
#list_component_versions(params = {}) ⇒ Types::ListComponentVersionsResponse
Retrieves a paginated list of all versions for a component.
-
#list_components(params = {}) ⇒ Types::ListComponentsResponse
Retrieves a paginated list of component summaries.
-
#list_core_devices(params = {}) ⇒ Types::ListCoreDevicesResponse
Retrieves a paginated list of Greengrass core devices.
-
#list_deployments(params = {}) ⇒ Types::ListDeploymentsResponse
Retrieves a paginated list of deployments.
-
#list_effective_deployments(params = {}) ⇒ Types::ListEffectiveDeploymentsResponse
Retrieves a paginated list of deployment jobs that IoT Greengrass sends to Greengrass core devices.
-
#list_installed_components(params = {}) ⇒ Types::ListInstalledComponentsResponse
Retrieves a paginated list of the components that a Greengrass core device runs.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the list of tags for an IoT Greengrass resource.
-
#resolve_component_candidates(params = {}) ⇒ Types::ResolveComponentCandidatesResponse
Retrieves a list of components that meet the component, version, and platform requirements of a deployment.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to an IoT Greengrass resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from an IoT Greengrass resource.
-
#update_connectivity_info(params = {}) ⇒ Types::UpdateConnectivityInfoResponse
Updates connectivity information for a Greengrass core device.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2239 2240 2241 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 2239 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2242 2243 2244 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 2242 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_service_role_to_account(params = {}) ⇒ Types::AssociateServiceRoleToAccountResponse
Associates a Greengrass service role with IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region. IoT Greengrass uses this role to verify the identity of client devices and manage core device connectivity information. The role must include the AWSGreengrassResourceAccessRolePolicy managed policy or a custom policy that defines equivalent permissions for the IoT Greengrass features that you use. For more information, see Greengrass service role in the IoT Greengrass Version 2 Developer Guide.
86 |
# File 'sig/client.rbs', line 86
def associate_service_role_to_account: (
|
#batch_associate_client_device_with_core_device(params = {}) ⇒ Types::BatchAssociateClientDeviceWithCoreDeviceResponse
Associates a list of client devices with a core device. Use this API operation to specify which client devices can discover a core device through cloud discovery. With cloud discovery, client devices connect to IoT Greengrass to retrieve associated core devices' connectivity information and certificates. For more information, see Configure cloud discovery in the IoT Greengrass V2 Developer Guide.
96 |
# File 'sig/client.rbs', line 96
def batch_associate_client_device_with_core_device: (
|
#batch_disassociate_client_device_from_core_device(params = {}) ⇒ Types::BatchDisassociateClientDeviceFromCoreDeviceResponse
Disassociates a list of client devices from a core device. After you disassociate a client device from a core device, the client device won't be able to use cloud discovery to retrieve the core device's connectivity information and certificates.
111 |
# File 'sig/client.rbs', line 111
def batch_disassociate_client_device_from_core_device: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 2212 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::GreengrassV2') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-greengrassv2' context[:gem_version] = '1.74.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_deployment(params = {}) ⇒ Types::CancelDeploymentResponse
Cancels a deployment. This operation cancels the deployment for devices that haven't yet received it. If a device already received the deployment, this operation doesn't change anything for that device.
126 |
# File 'sig/client.rbs', line 126
def cancel_deployment: (
|
#create_component_version(params = {}) ⇒ Types::CreateComponentVersionResponse
Creates a component. Components are software that run on Greengrass core devices. After you develop and test a component on your core device, you can use this operation to upload your component to IoT Greengrass. Then, you can deploy the component to other core devices.
You can use this operation to do the following:
-
Create components from recipes
Create a component from a recipe, which is a file that defines the component's metadata, parameters, dependencies, lifecycle, artifacts, and platform capability. For more information, see IoT Greengrass component recipe reference in the IoT Greengrass V2 Developer Guide.
To create a component from a recipe, specify
inlineRecipewhen you call this operation. -
Create components from Lambda functions
Create a component from an Lambda function that runs on IoT Greengrass. This creates a recipe and artifacts from the Lambda function's deployment package. You can use this operation to migrate Lambda functions from IoT Greengrass V1 to IoT Greengrass V2.
This function accepts Lambda functions in all supported versions of Python, Node.js, and Java runtimes. IoT Greengrass doesn't apply any additional restrictions on deprecated Lambda runtime versions.
To create a component from a Lambda function, specify
lambdaFunctionwhen you call this operation.IoT Greengrass currently supports Lambda functions on only Linux core devices.
140 |
# File 'sig/client.rbs', line 140
def create_component_version: (
|
#create_deployment(params = {}) ⇒ Types::CreateDeploymentResponse
Creates a continuous deployment for a target, which is a Greengrass core device or group of core devices. When you add a new core device to a group of core devices that has a deployment, IoT Greengrass deploys that group's deployment to the new device.
You can define one deployment for each target. When you create a new deployment for a target that has an existing deployment, you replace the previous deployment. IoT Greengrass applies the new deployment to the target devices.
Every deployment has a revision number that indicates how many deployment revisions you define for a target. Use this operation to create a new revision of an existing deployment.
For more information, see the Create deployments in the IoT Greengrass V2 Developer Guide.
208 |
# File 'sig/client.rbs', line 208
def create_deployment: (
|
#delete_component(params = {}) ⇒ Struct
Deletes a version of a component from IoT Greengrass.
269 |
# File 'sig/client.rbs', line 269
def delete_component: (
|
#delete_core_device(params = {}) ⇒ Struct
Deletes a Greengrass core device, which is an IoT thing. This operation removes the core device from the list of core devices. This operation doesn't delete the IoT thing. For more information about how to delete the IoT thing, see DeleteThing in the IoT API Reference.
275 |
# File 'sig/client.rbs', line 275
def delete_core_device: (
|
#delete_deployment(params = {}) ⇒ Struct
Deletes a deployment. To delete an active deployment, you must first cancel it. For more information, see CancelDeployment.
Deleting a deployment doesn't affect core devices that run that deployment, because core devices store the deployment's configuration on the device. Additionally, core devices can roll back to a previous deployment that has been deleted.
281 |
# File 'sig/client.rbs', line 281
def delete_deployment: (
|
#describe_component(params = {}) ⇒ Types::DescribeComponentResponse
Retrieves metadata for a version of a component.
299 |
# File 'sig/client.rbs', line 299
def describe_component: (
|
#disassociate_service_role_from_account(params = {}) ⇒ Types::DisassociateServiceRoleFromAccountResponse
Disassociates the Greengrass service role from IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region. Without a service role, IoT Greengrass can't verify the identity of client devices or manage core device connectivity information. For more information, see Greengrass service role in the IoT Greengrass Version 2 Developer Guide.
309 |
# File 'sig/client.rbs', line 309
def disassociate_service_role_from_account: (
|
#get_component(params = {}) ⇒ Types::GetComponentResponse
Gets the recipe for a version of a component.
320 |
# File 'sig/client.rbs', line 320
def get_component: (
|
#get_component_version_artifact(params = {}) ⇒ Types::GetComponentVersionArtifactResponse
Gets the pre-signed URL to download a public or a Lambda component artifact. Core devices call this operation to identify the URL that they can use to download an artifact to install.
331 |
# File 'sig/client.rbs', line 331
def get_component_version_artifact: (
|
#get_connectivity_info(params = {}) ⇒ Types::GetConnectivityInfoResponse
Retrieves connectivity information for a Greengrass core device.
Connectivity information includes endpoints and ports where client devices can connect to an MQTT broker on the core device. When a client device calls the IoT Greengrass discovery API, IoT Greengrass returns connectivity information for all of the core devices where the client device can connect. For more information, see Connect client devices to core devices in the IoT Greengrass Version 2 Developer Guide.
345 |
# File 'sig/client.rbs', line 345
def get_connectivity_info: (
|
#get_core_device(params = {}) ⇒ Types::GetCoreDeviceResponse
Retrieves metadata for a Greengrass core device.
Core devices send status updates at the following times:
-
When the IoT Greengrass Core software starts
-
When the core device receives a deployment from the Amazon Web Services Cloud
-
When the status of any component on the core device becomes
BROKEN -
At a regular interval that you can configure, which defaults to 24 hours
-
For IoT Greengrass Core v2.7.0, the core device sends status updates upon local deployment and cloud deployment
362 |
# File 'sig/client.rbs', line 362
def get_core_device: (
|
#get_deployment(params = {}) ⇒ Types::GetDeploymentResponse
Gets a deployment. Deployments define the components that run on Greengrass core devices.
385 |
# File 'sig/client.rbs', line 385
def get_deployment: (
|
#get_service_role_for_account(params = {}) ⇒ Types::GetServiceRoleForAccountResponse
Gets the service role associated with IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region. IoT Greengrass uses this role to verify the identity of client devices and manage core device connectivity information. For more information, see Greengrass service role in the IoT Greengrass Version 2 Developer Guide.
396 |
# File 'sig/client.rbs', line 396
def get_service_role_for_account: (
|
#list_client_devices_associated_with_core_device(params = {}) ⇒ Types::ListClientDevicesAssociatedWithCoreDeviceResponse
Retrieves a paginated list of client devices that are associated with a core device.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
406 |
# File 'sig/client.rbs', line 406
def list_client_devices_associated_with_core_device: (
|
#list_component_versions(params = {}) ⇒ Types::ListComponentVersionsResponse
Retrieves a paginated list of all versions for a component. Greater versions are listed first.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
419 |
# File 'sig/client.rbs', line 419
def list_component_versions: (
|
#list_components(params = {}) ⇒ Types::ListComponentsResponse
Retrieves a paginated list of component summaries. This list includes components that you have permission to view.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
432 |
# File 'sig/client.rbs', line 432
def list_components: (
|
#list_core_devices(params = {}) ⇒ Types::ListCoreDevicesResponse
Retrieves a paginated list of Greengrass core devices.
Core devices send status updates at the following times:
-
When the IoT Greengrass Core software starts
-
When the core device receives a deployment from the Amazon Web Services Cloud
-
For Greengrass nucleus 2.12.2 and earlier, the core device sends status updates when the status of any component on the core device becomes
ERROREDorBROKEN. -
For Greengrass nucleus 2.12.3 and later, the core device sends status updates when the status of any component on the core device becomes
ERRORED,BROKEN,RUNNING, orFINISHED. -
At a regular interval that you can configure, which defaults to 24 hours
-
For IoT Greengrass Core v2.7.0, the core device sends status updates upon local deployment and cloud deployment
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
445 |
# File 'sig/client.rbs', line 445
def list_core_devices: (
|
#list_deployments(params = {}) ⇒ Types::ListDeploymentsResponse
Retrieves a paginated list of deployments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
460 |
# File 'sig/client.rbs', line 460
def list_deployments: (
|
#list_effective_deployments(params = {}) ⇒ Types::ListEffectiveDeploymentsResponse
Retrieves a paginated list of deployment jobs that IoT Greengrass sends to Greengrass core devices.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
475 |
# File 'sig/client.rbs', line 475
def list_effective_deployments: (
|
#list_installed_components(params = {}) ⇒ Types::ListInstalledComponentsResponse
Retrieves a paginated list of the components that a Greengrass core
device runs. By default, this list doesn't include components that
are deployed as dependencies of other components. To include
dependencies in the response, set the topologyFilter parameter to
ALL.
Core devices send status updates at the following times:
-
When the IoT Greengrass Core software starts
-
When the core device receives a deployment from the Amazon Web Services Cloud
-
When the status of any component on the core device becomes
BROKEN -
At a regular interval that you can configure, which defaults to 24 hours
-
For IoT Greengrass Core v2.7.0, the core device sends status updates upon local deployment and cloud deployment
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
488 |
# File 'sig/client.rbs', line 488
def list_installed_components: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the list of tags for an IoT Greengrass resource.
501 |
# File 'sig/client.rbs', line 501
def list_tags_for_resource: (
|
#resolve_component_candidates(params = {}) ⇒ Types::ResolveComponentCandidatesResponse
Retrieves a list of components that meet the component, version, and platform requirements of a deployment. Greengrass core devices call this operation when they receive a deployment to identify the components to install.
This operation identifies components that meet all dependency
requirements for a deployment. If the requirements conflict, then this
operation returns an error and the deployment fails. For example, this
occurs if component A requires version >2.0.0 and component B
requires version <2.0.0 of a component dependency.
When you specify the component candidates to resolve, IoT Greengrass compares each component's digest from the core device with the component's digest in the Amazon Web Services Cloud. If the digests don't match, then IoT Greengrass specifies to use the version from the Amazon Web Services Cloud.
To use this operation, you must use the data plane API endpoint and authenticate with an IoT device certificate. For more information, see IoT Greengrass endpoints and quotas.
511 |
# File 'sig/client.rbs', line 511
def resolve_component_candidates: (
|
#tag_resource(params = {}) ⇒ Struct
Adds tags to an IoT Greengrass resource. If a tag already exists for the resource, this operation updates the tag's value.
530 |
# File 'sig/client.rbs', line 530
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a tag from an IoT Greengrass resource.
540 |
# File 'sig/client.rbs', line 540
def untag_resource: (
|
#update_connectivity_info(params = {}) ⇒ Types::UpdateConnectivityInfoResponse
Updates connectivity information for a Greengrass core device.
Connectivity information includes endpoints and ports where client devices can connect to an MQTT broker on the core device. When a client device calls the IoT Greengrass discovery API, IoT Greengrass returns connectivity information for all of the core devices where the client device can connect. For more information, see Connect client devices to core devices in the IoT Greengrass Version 2 Developer Guide.
552 |
# File 'sig/client.rbs', line 552
def update_connectivity_info: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2232 2233 2234 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 2232 def waiter_names [] end |