Class: Aws::GreengrassV2::Types::CancelDeploymentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::CancelDeploymentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
A message that communicates if the cancel was successful.
Instance Attribute Details
#message ⇒ String
A message that communicates if the cancel was successful.
252 253 254 255 256 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 252 class CancelDeploymentResponse < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |