Class: Aws::GreengrassV2::Types::CloudComponentStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::CloudComponentStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
Contains the status of a component in the IoT Greengrass service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_state ⇒ String
The state of the component.
-
#errors ⇒ Hash<String,String>
A dictionary of errors that communicate why the component is in an error state.
-
#message ⇒ String
A message that communicates details, such as errors, about the status of the component.
Instance Attribute Details
#component_state ⇒ String
The state of the component.
278 279 280 281 282 283 284 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 278 class CloudComponentStatus < Struct.new( :component_state, :message, :errors) SENSITIVE = [] include Aws::Structure end |
#errors ⇒ Hash<String,String>
A dictionary of errors that communicate why the component is in an error state. For example, if IoT Greengrass can't access an artifact for the component, then `errors` contains the artifact's URI as a key, and the error message as the value for that key.
278 279 280 281 282 283 284 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 278 class CloudComponentStatus < Struct.new( :component_state, :message, :errors) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A message that communicates details, such as errors, about the status of the component.
278 279 280 281 282 283 284 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 278 class CloudComponentStatus < Struct.new( :component_state, :message, :errors) SENSITIVE = [] include Aws::Structure end |