Class: Aws::GreengrassV2::Types::ComponentCandidate
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::ComponentCandidate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
Note:
When making an API call, you may pass ComponentCandidate data as a hash:
{
component_name: "ComponentNameString",
component_version: "ComponentVersionString",
version_requirements: {
"NonEmptyString" => "NonEmptyString",
},
}
Contains information about a component that is a candidate to deploy to a Greengrass core device.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_name ⇒ String
The name of the component.
-
#component_version ⇒ String
The version of the component.
-
#version_requirements ⇒ Hash<String,String>
The version requirements for the component's dependencies.
Instance Attribute Details
#component_name ⇒ String
The name of the component.
380 381 382 383 384 385 386 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 380 class ComponentCandidate < Struct.new( :component_name, :component_version, :version_requirements) SENSITIVE = [] include Aws::Structure end |
#component_version ⇒ String
The version of the component.
380 381 382 383 384 385 386 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 380 class ComponentCandidate < Struct.new( :component_name, :component_version, :version_requirements) SENSITIVE = [] include Aws::Structure end |
#version_requirements ⇒ Hash<String,String>
The version requirements for the component's dependencies. Greengrass core devices get the version requirements from component recipes.
IoT Greengrass V2 uses semantic version constraints. For more information, see [Semantic Versioning].
[1]: semver.org/
380 381 382 383 384 385 386 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 380 class ComponentCandidate < Struct.new( :component_name, :component_version, :version_requirements) SENSITIVE = [] include Aws::Structure end |