Class: Aws::GreengrassV2::Types::ComponentDeploymentSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::ComponentDeploymentSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
When making an API call, you may pass ComponentDeploymentSpecification data as a hash:
{
component_version: "ComponentVersionString",
configuration_update: {
merge: "ComponentConfigurationString",
reset: ["ComponentConfigurationPath"],
},
run_with: {
posix_user: "NonEmptyString",
system_resource_limits: {
memory: 1,
cpus: 1.0,
},
windows_user: "NonEmptyString",
},
}
Contains information about a component to deploy.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_version ⇒ String
The version of the component.
-
#configuration_update ⇒ Types::ComponentConfigurationUpdate
The configuration updates to deploy for the component.
-
#run_with ⇒ Types::ComponentRunWith
The system user and group that the IoT Greengrass Core software uses to run component processes on the core device.
Instance Attribute Details
#component_version ⇒ String
The version of the component.
512 513 514 515 516 517 518 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 512 class ComponentDeploymentSpecification < Struct.new( :component_version, :configuration_update, :run_with) SENSITIVE = [] include Aws::Structure end |
#configuration_update ⇒ Types::ComponentConfigurationUpdate
The configuration updates to deploy for the component. You can define reset updates and merge updates. A reset updates the keys that you specify to the default configuration for the component. A merge updates the core device's component configuration with the keys and values that you specify. The IoT Greengrass Core software applies reset updates before it applies merge updates. For more information, see [Update component configurations] in the *IoT Greengrass V2 Developer Guide*.
[1]: docs.aws.amazon.com/greengrass/v2/developerguide/update-component-configurations.html
512 513 514 515 516 517 518 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 512 class ComponentDeploymentSpecification < Struct.new( :component_version, :configuration_update, :run_with) SENSITIVE = [] include Aws::Structure end |
#run_with ⇒ Types::ComponentRunWith
The system user and group that the IoT Greengrass Core software uses to run component processes on the core device. If you omit this parameter, the IoT Greengrass Core software uses the system user and group that you configure for the core device. For more information, see [Configure the user and group that run components] in the *IoT Greengrass V2 Developer Guide*.
512 513 514 515 516 517 518 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 512 class ComponentDeploymentSpecification < Struct.new( :component_version, :configuration_update, :run_with) SENSITIVE = [] include Aws::Structure end |