Class: Aws::GreengrassV2::Types::ConnectivityInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::ConnectivityInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
When making an API call, you may pass ConnectivityInfo data as a hash:
{
id: "String",
host_address: "String",
port_number: 1,
metadata: "String",
}
Contains information about an endpoint and port where client devices can connect to an MQTT broker on a Greengrass core device.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#host_address ⇒ String
The IP address or DNS address where client devices can connect to an MQTT broker on the Greengrass core device.
-
#id ⇒ String
An ID for the connectivity information.
-
#metadata ⇒ String
Additional metadata to provide to client devices that connect to this core device.
-
#port_number ⇒ Integer
The port where the MQTT broker operates on the core device.
Instance Attribute Details
#host_address ⇒ String
The IP address or DNS address where client devices can connect to an MQTT broker on the Greengrass core device.
803 804 805 806 807 808 809 810 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 803 class ConnectivityInfo < Struct.new( :id, :host_address, :port_number, :metadata) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
An ID for the connectivity information.
803 804 805 806 807 808 809 810 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 803 class ConnectivityInfo < Struct.new( :id, :host_address, :port_number, :metadata) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ String
Additional metadata to provide to client devices that connect to this core device.
803 804 805 806 807 808 809 810 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 803 class ConnectivityInfo < Struct.new( :id, :host_address, :port_number, :metadata) SENSITIVE = [] include Aws::Structure end |
#port_number ⇒ Integer
The port where the MQTT broker operates on the core device. This port is typically 8883, which is the default port for the MQTT broker component that runs on core devices.
803 804 805 806 807 808 809 810 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 803 class ConnectivityInfo < Struct.new( :id, :host_address, :port_number, :metadata) SENSITIVE = [] include Aws::Structure end |