Class: Aws::GreengrassV2::Types::Deployment
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::Deployment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
Contains information about a deployment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ Time
The time at which the deployment was created, expressed in ISO 8601 format.
-
#deployment_id ⇒ String
The ID of the deployment.
-
#deployment_name ⇒ String
The name of the deployment.
-
#deployment_status ⇒ String
The status of the deployment.
-
#is_latest_for_target ⇒ Boolean
Whether or not the deployment is the latest revision for its target.
-
#revision_id ⇒ String
The revision number of the deployment.
-
#target_arn ⇒ String
The [ARN] of the target IoT thing or thing group.
Instance Attribute Details
#creation_timestamp ⇒ Time
The time at which the deployment was created, expressed in ISO 8601 format.
1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1261 class Deployment < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :creation_timestamp, :deployment_status, :is_latest_for_target) SENSITIVE = [] include Aws::Structure end |
#deployment_id ⇒ String
The ID of the deployment.
1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1261 class Deployment < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :creation_timestamp, :deployment_status, :is_latest_for_target) SENSITIVE = [] include Aws::Structure end |
#deployment_name ⇒ String
The name of the deployment.
1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1261 class Deployment < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :creation_timestamp, :deployment_status, :is_latest_for_target) SENSITIVE = [] include Aws::Structure end |
#deployment_status ⇒ String
The status of the deployment.
1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1261 class Deployment < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :creation_timestamp, :deployment_status, :is_latest_for_target) SENSITIVE = [] include Aws::Structure end |
#is_latest_for_target ⇒ Boolean
Whether or not the deployment is the latest revision for its target.
1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1261 class Deployment < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :creation_timestamp, :deployment_status, :is_latest_for_target) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
The revision number of the deployment.
1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1261 class Deployment < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :creation_timestamp, :deployment_status, :is_latest_for_target) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The [ARN] of the target IoT thing or thing group.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1261 class Deployment < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :creation_timestamp, :deployment_status, :is_latest_for_target) SENSITIVE = [] include Aws::Structure end |