Class: Aws::GreengrassV2::Types::DeploymentPolicies
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::DeploymentPolicies
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
When making an API call, you may pass DeploymentPolicies data as a hash:
{
failure_handling_policy: "ROLLBACK", # accepts ROLLBACK, DO_NOTHING
component_update_policy: {
timeout_in_seconds: 1,
action: "NOTIFY_COMPONENTS", # accepts NOTIFY_COMPONENTS, SKIP_NOTIFY_COMPONENTS
},
configuration_validation_policy: {
timeout_in_seconds: 1,
},
}
Contains information about policies that define how a deployment updates components and handles failure.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_update_policy ⇒ Types::DeploymentComponentUpdatePolicy
The component update policy for the configuration deployment.
-
#configuration_validation_policy ⇒ Types::DeploymentConfigurationValidationPolicy
The configuration validation policy for the configuration deployment.
-
#failure_handling_policy ⇒ String
The failure handling policy for the configuration deployment.
Instance Attribute Details
#component_update_policy ⇒ Types::DeploymentComponentUpdatePolicy
The component update policy for the configuration deployment. This policy defines when it's safe to deploy the configuration to devices.
1486 1487 1488 1489 1490 1491 1492 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1486 class DeploymentPolicies < Struct.new( :failure_handling_policy, :component_update_policy, :configuration_validation_policy) SENSITIVE = [] include Aws::Structure end |
#configuration_validation_policy ⇒ Types::DeploymentConfigurationValidationPolicy
The configuration validation policy for the configuration deployment. This policy defines how long each component has to validate its configure updates.
1486 1487 1488 1489 1490 1491 1492 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1486 class DeploymentPolicies < Struct.new( :failure_handling_policy, :component_update_policy, :configuration_validation_policy) SENSITIVE = [] include Aws::Structure end |
#failure_handling_policy ⇒ String
The failure handling policy for the configuration deployment. This policy defines what to do if the deployment fails.
Default: `ROLLBACK`
1486 1487 1488 1489 1490 1491 1492 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1486 class DeploymentPolicies < Struct.new( :failure_handling_policy, :component_update_policy, :configuration_validation_policy) SENSITIVE = [] include Aws::Structure end |