Class: Aws::GreengrassV2::Types::EffectiveDeployment
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::EffectiveDeployment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
Contains information about a deployment job that IoT Greengrass sends to a Greengrass core device.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#core_device_execution_status ⇒ String
The status of the deployment job on the Greengrass core device.
-
#creation_timestamp ⇒ Time
The time at which the deployment was created, expressed in ISO 8601 format.
-
#deployment_id ⇒ String
The ID of the deployment.
-
#deployment_name ⇒ String
The name of the deployment.
-
#description ⇒ String
The description of the deployment job.
-
#iot_job_arn ⇒ String
The [ARN] of the IoT job that applies the deployment to target devices.
-
#iot_job_id ⇒ String
The ID of the IoT job that applies the deployment to target devices.
-
#modified_timestamp ⇒ Time
The time at which the deployment job was last modified, expressed in ISO 8601 format.
-
#reason ⇒ String
The reason code for the update, if the job was updated.
-
#status_details ⇒ Types::EffectiveDeploymentStatusDetails
The status details that explain why a deployment has an error.
-
#target_arn ⇒ String
The [ARN] of the target IoT thing or thing group.
Instance Attribute Details
#core_device_execution_status ⇒ String
The status of the deployment job on the Greengrass core device.
1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1722 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp, :status_details) SENSITIVE = [] include Aws::Structure end |
#creation_timestamp ⇒ Time
The time at which the deployment was created, expressed in ISO 8601 format.
1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1722 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp, :status_details) SENSITIVE = [] include Aws::Structure end |
#deployment_id ⇒ String
The ID of the deployment.
1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1722 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp, :status_details) SENSITIVE = [] include Aws::Structure end |
#deployment_name ⇒ String
The name of the deployment.
1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1722 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp, :status_details) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the deployment job.
1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1722 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp, :status_details) SENSITIVE = [] include Aws::Structure end |
#iot_job_arn ⇒ String
The [ARN] of the IoT job that applies the deployment to target devices.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1722 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp, :status_details) SENSITIVE = [] include Aws::Structure end |
#iot_job_id ⇒ String
The ID of the IoT job that applies the deployment to target devices.
1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1722 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp, :status_details) SENSITIVE = [] include Aws::Structure end |
#modified_timestamp ⇒ Time
The time at which the deployment job was last modified, expressed in ISO 8601 format.
1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1722 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp, :status_details) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
The reason code for the update, if the job was updated.
1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1722 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp, :status_details) SENSITIVE = [] include Aws::Structure end |
#status_details ⇒ Types::EffectiveDeploymentStatusDetails
The status details that explain why a deployment has an error. This response will be null if the deployment is in a success state.
1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1722 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp, :status_details) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The [ARN] of the target IoT thing or thing group.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1722 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp, :status_details) SENSITIVE = [] include Aws::Structure end |