Class: Aws::GreengrassV2::Types::EffectiveDeploymentStatusDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::EffectiveDeploymentStatusDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
Contains all error-related information for the deployment record. The status details will be null if the deployment is in a success state.
<note markdown=“1”> Greengrass nucleus v2.8.0 or later is required to get an accurate `errorStack` and `errorTypes` response. This field will not be returned for earlier Greengrass nucleus versions.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_stack ⇒ Array<String>
Contains an ordered list of short error codes that range from the most generic error to the most specific one.
-
#error_types ⇒ Array<String>
Contains tags which describe the error.
Instance Attribute Details
#error_stack ⇒ Array<String>
Contains an ordered list of short error codes that range from the most generic error to the most specific one. The error codes describe the reason for failure whenever the `coreDeviceExecutionStatus` is in a failed state. The response will be an empty list if there is no error.
1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1742 class EffectiveDeploymentStatusDetails < Struct.new( :error_stack, :error_types) SENSITIVE = [] include Aws::Structure end |
#error_types ⇒ Array<String>
Contains tags which describe the error. You can use the error types to classify errors to assist with remediating the failure. The response will be an empty list if there is no error.
1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1742 class EffectiveDeploymentStatusDetails < Struct.new( :error_stack, :error_types) SENSITIVE = [] include Aws::Structure end |