Class: Aws::GreengrassV2::Types::GetServiceRoleForAccountResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::GetServiceRoleForAccountResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_at ⇒ String
The time when the service role was associated with IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region.
-
#role_arn ⇒ String
The ARN of the service role that is associated with IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region.
Instance Attribute Details
#associated_at ⇒ String
The time when the service role was associated with IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region.
2108 2109 2110 2111 2112 2113 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2108 class GetServiceRoleForAccountResponse < Struct.new( :associated_at, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the service role that is associated with IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region.
2108 2109 2110 2111 2112 2113 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2108 class GetServiceRoleForAccountResponse < Struct.new( :associated_at, :role_arn) SENSITIVE = [] include Aws::Structure end |