Class: Aws::GreengrassV2::Types::InstalledComponent
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::InstalledComponent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
Contains information about a component on a Greengrass core device.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_name ⇒ String
The name of the component.
-
#component_version ⇒ String
The version of the component.
-
#is_root ⇒ Boolean
Whether or not the component is a root component.
-
#last_installation_source ⇒ String
The most recent deployment source that brought the component to the Greengrass core device.
-
#last_reported_timestamp ⇒ Time
The last time the Greengrass core device sent a message containing a certain component to the Amazon Web Services Cloud.
-
#last_status_change_timestamp ⇒ Time
The status of how current the data is.
-
#lifecycle_state ⇒ String
The lifecycle state of the component.
-
#lifecycle_state_details ⇒ String
A detailed response about the lifecycle state of the component that explains the reason why a component has an error or is broken.
-
#lifecycle_status_codes ⇒ Array<String>
The status codes that indicate the reason for failure whenever the `lifecycleState` has an error or is in a broken state.
Instance Attribute Details
#component_name ⇒ String
The name of the component.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2205 class InstalledComponent < Struct.new( :component_name, :component_version, :lifecycle_state, :lifecycle_state_details, :is_root, :last_status_change_timestamp, :last_reported_timestamp, :last_installation_source, :lifecycle_status_codes) SENSITIVE = [] include Aws::Structure end |
#component_version ⇒ String
The version of the component.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2205 class InstalledComponent < Struct.new( :component_name, :component_version, :lifecycle_state, :lifecycle_state_details, :is_root, :last_status_change_timestamp, :last_reported_timestamp, :last_installation_source, :lifecycle_status_codes) SENSITIVE = [] include Aws::Structure end |
#is_root ⇒ Boolean
Whether or not the component is a root component.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2205 class InstalledComponent < Struct.new( :component_name, :component_version, :lifecycle_state, :lifecycle_state_details, :is_root, :last_status_change_timestamp, :last_reported_timestamp, :last_installation_source, :lifecycle_status_codes) SENSITIVE = [] include Aws::Structure end |
#last_installation_source ⇒ String
The most recent deployment source that brought the component to the Greengrass core device. For a thing group deployment or thing deployment, the source will be the The ID of the deployment. and for local deployments it will be `LOCAL`.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2205 class InstalledComponent < Struct.new( :component_name, :component_version, :lifecycle_state, :lifecycle_state_details, :is_root, :last_status_change_timestamp, :last_reported_timestamp, :last_installation_source, :lifecycle_status_codes) SENSITIVE = [] include Aws::Structure end |
#last_reported_timestamp ⇒ Time
The last time the Greengrass core device sent a message containing a certain component to the Amazon Web Services Cloud.
A component does not need to see a state change for this field to update.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2205 class InstalledComponent < Struct.new( :component_name, :component_version, :lifecycle_state, :lifecycle_state_details, :is_root, :last_status_change_timestamp, :last_reported_timestamp, :last_installation_source, :lifecycle_status_codes) SENSITIVE = [] include Aws::Structure end |
#last_status_change_timestamp ⇒ Time
The status of how current the data is.
This response is based off of component state changes. The status reflects component disruptions and deployments. If a component only sees a configuration update during a deployment, it might not undergo a state change and this status would not be updated.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2205 class InstalledComponent < Struct.new( :component_name, :component_version, :lifecycle_state, :lifecycle_state_details, :is_root, :last_status_change_timestamp, :last_reported_timestamp, :last_installation_source, :lifecycle_status_codes) SENSITIVE = [] include Aws::Structure end |
#lifecycle_state ⇒ String
The lifecycle state of the component.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2205 class InstalledComponent < Struct.new( :component_name, :component_version, :lifecycle_state, :lifecycle_state_details, :is_root, :last_status_change_timestamp, :last_reported_timestamp, :last_installation_source, :lifecycle_status_codes) SENSITIVE = [] include Aws::Structure end |
#lifecycle_state_details ⇒ String
A detailed response about the lifecycle state of the component that explains the reason why a component has an error or is broken.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2205 class InstalledComponent < Struct.new( :component_name, :component_version, :lifecycle_state, :lifecycle_state_details, :is_root, :last_status_change_timestamp, :last_reported_timestamp, :last_installation_source, :lifecycle_status_codes) SENSITIVE = [] include Aws::Structure end |
#lifecycle_status_codes ⇒ Array<String>
The status codes that indicate the reason for failure whenever the `lifecycleState` has an error or is in a broken state.
<note markdown=“1”> Greengrass nucleus v2.8.0 or later is required to get an accurate `lifecycleStatusCodes` response. This response can be inaccurate in earlier Greengrass nucleus versions.
</note>
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2205 class InstalledComponent < Struct.new( :component_name, :component_version, :lifecycle_state, :lifecycle_state_details, :is_root, :last_status_change_timestamp, :last_reported_timestamp, :last_installation_source, :lifecycle_status_codes) SENSITIVE = [] include Aws::Structure end |