Class: Aws::GreengrassV2::Types::InternalServerException
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::InternalServerException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
IoT Greengrass can't process your request right now. Try again later.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#retry_after_seconds ⇒ Integer
The amount of time to wait before you retry the request.
Instance Attribute Details
#message ⇒ String
2122 2123 2124 2125 2126 2127 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2122 class InternalServerException < Struct.new( :message, :retry_after_seconds) SENSITIVE = [] include Aws::Structure end |
#retry_after_seconds ⇒ Integer
The amount of time to wait before you retry the request.
2122 2123 2124 2125 2126 2127 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2122 class InternalServerException < Struct.new( :message, :retry_after_seconds) SENSITIVE = [] include Aws::Structure end |