Class: Aws::GreengrassV2::Types::IoTJobAbortCriteria

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-greengrassv2/types.rb

Overview

Note:

When making an API call, you may pass IoTJobAbortCriteria data as a hash:

{
  failure_type: "FAILED", # required, accepts FAILED, REJECTED, TIMED_OUT, ALL
  action: "CANCEL", # required, accepts CANCEL
  threshold_percentage: 1.0, # required
  min_number_of_executed_things: 1, # required
}

Contains criteria that define when and how to cancel a job.

The deployment stops if the following conditions are true:

  1. The number of things that receive the deployment exceeds the `minNumberOfExecutedThings`.

  2. The percentage of failures with type `failureType` exceeds the `thresholdPercentage`.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action to perform when the criteria are met.

Returns:

  • (String)


2212
2213
2214
2215
2216
2217
2218
2219
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2212

class IoTJobAbortCriteria < Struct.new(
  :failure_type,
  :action,
  :threshold_percentage,
  :min_number_of_executed_things)
  SENSITIVE = []
  include Aws::Structure
end

#failure_typeString

The type of job deployment failure that can cancel a job.

Returns:

  • (String)


2212
2213
2214
2215
2216
2217
2218
2219
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2212

class IoTJobAbortCriteria < Struct.new(
  :failure_type,
  :action,
  :threshold_percentage,
  :min_number_of_executed_things)
  SENSITIVE = []
  include Aws::Structure
end

#min_number_of_executed_thingsInteger

The minimum number of things that receive the configuration before the job can cancel.

Returns:

  • (Integer)


2212
2213
2214
2215
2216
2217
2218
2219
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2212

class IoTJobAbortCriteria < Struct.new(
  :failure_type,
  :action,
  :threshold_percentage,
  :min_number_of_executed_things)
  SENSITIVE = []
  include Aws::Structure
end

#threshold_percentageFloat

The minimum percentage of `failureType` failures that occur before the job can cancel.

This parameter supports up to two digits after the decimal (for example, you can specify `10.9` or `10.99`, but not `10.999`).

Returns:

  • (Float)


2212
2213
2214
2215
2216
2217
2218
2219
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2212

class IoTJobAbortCriteria < Struct.new(
  :failure_type,
  :action,
  :threshold_percentage,
  :min_number_of_executed_things)
  SENSITIVE = []
  include Aws::Structure
end