Class: Aws::GreengrassV2::Types::IoTJobExponentialRolloutRate
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::IoTJobExponentialRolloutRate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
When making an API call, you may pass IoTJobExponentialRolloutRate data as a hash:
{
base_rate_per_minute: 1, # required
increment_factor: 1.0, # required
rate_increase_criteria: { # required
number_of_notified_things: 1,
number_of_succeeded_things: 1,
},
}
Contains information about an exponential rollout rate for a configuration deployment job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#base_rate_per_minute ⇒ Integer
The minimum number of devices that receive a pending job notification, per minute, when the job starts.
-
#increment_factor ⇒ Float
The exponential factor to increase the rollout rate for the job.
-
#rate_increase_criteria ⇒ Types::IoTJobRateIncreaseCriteria
The criteria to increase the rollout rate for the job.
Instance Attribute Details
#base_rate_per_minute ⇒ Integer
The minimum number of devices that receive a pending job notification, per minute, when the job starts. This parameter defines the initial rollout rate of the job.
2390 2391 2392 2393 2394 2395 2396 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2390 class IoTJobExponentialRolloutRate < Struct.new( :base_rate_per_minute, :increment_factor, :rate_increase_criteria) SENSITIVE = [] include Aws::Structure end |
#increment_factor ⇒ Float
The exponential factor to increase the rollout rate for the job.
This parameter supports up to one digit after the decimal (for example, you can specify `1.5`, but not `1.55`).
2390 2391 2392 2393 2394 2395 2396 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2390 class IoTJobExponentialRolloutRate < Struct.new( :base_rate_per_minute, :increment_factor, :rate_increase_criteria) SENSITIVE = [] include Aws::Structure end |
#rate_increase_criteria ⇒ Types::IoTJobRateIncreaseCriteria
The criteria to increase the rollout rate for the job.
2390 2391 2392 2393 2394 2395 2396 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2390 class IoTJobExponentialRolloutRate < Struct.new( :base_rate_per_minute, :increment_factor, :rate_increase_criteria) SENSITIVE = [] include Aws::Structure end |