Class: Aws::GreengrassV2::Types::LambdaContainerParams
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::LambdaContainerParams
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
Note:
When making an API call, you may pass LambdaContainerParams data as a hash:
{
memory_size_in_kb: 1,
mount_ro_sysfs: false,
volumes: [
{
source_path: "FileSystemPath", # required
destination_path: "FileSystemPath", # required
permission: "ro", # accepts ro, rw
add_group_owner: false,
},
],
devices: [
{
path: "FileSystemPath", # required
permission: "ro", # accepts ro, rw
add_group_owner: false,
},
],
}
Contains information about a container in which Lambda functions run on Greengrass core devices.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#devices ⇒ Array<Types::LambdaDeviceMount>
The list of system devices that the container can access.
-
#memory_size_in_kb ⇒ Integer
The memory size of the container, expressed in kilobytes.
-
#mount_ro_sysfs ⇒ Boolean
Whether or not the container can read information from the device's `/sys` folder.
-
#volumes ⇒ Array<Types::LambdaVolumeMount>
The list of volumes that the container can access.
Instance Attribute Details
#devices ⇒ Array<Types::LambdaDeviceMount>
The list of system devices that the container can access.
2505 2506 2507 2508 2509 2510 2511 2512 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2505 class LambdaContainerParams < Struct.new( :memory_size_in_kb, :mount_ro_sysfs, :volumes, :devices) SENSITIVE = [] include Aws::Structure end |
#memory_size_in_kb ⇒ Integer
The memory size of the container, expressed in kilobytes.
Default: `16384` (16 MB)
2505 2506 2507 2508 2509 2510 2511 2512 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2505 class LambdaContainerParams < Struct.new( :memory_size_in_kb, :mount_ro_sysfs, :volumes, :devices) SENSITIVE = [] include Aws::Structure end |
#mount_ro_sysfs ⇒ Boolean
Whether or not the container can read information from the device's `/sys` folder.
Default: `false`
2505 2506 2507 2508 2509 2510 2511 2512 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2505 class LambdaContainerParams < Struct.new( :memory_size_in_kb, :mount_ro_sysfs, :volumes, :devices) SENSITIVE = [] include Aws::Structure end |
#volumes ⇒ Array<Types::LambdaVolumeMount>
The list of volumes that the container can access.
2505 2506 2507 2508 2509 2510 2511 2512 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2505 class LambdaContainerParams < Struct.new( :memory_size_in_kb, :mount_ro_sysfs, :volumes, :devices) SENSITIVE = [] include Aws::Structure end |