Class: Aws::GreengrassV2::Types::LambdaDeviceMount
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::LambdaDeviceMount
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
Contains information about a device that Linux processes in a container can access.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add_group_owner ⇒ Boolean
Whether or not to add the component's system user as an owner of the device.
-
#path ⇒ String
The mount path for the device in the file system.
-
#permission ⇒ String
The permission to access the device: read/only (`ro`) or read/write (`rw`).
Instance Attribute Details
#add_group_owner ⇒ Boolean
Whether or not to add the component's system user as an owner of the device.
Default: `false`
2057 2058 2059 2060 2061 2062 2063 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2057 class LambdaDeviceMount < Struct.new( :path, :permission, :add_group_owner) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The mount path for the device in the file system.
2057 2058 2059 2060 2061 2062 2063 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2057 class LambdaDeviceMount < Struct.new( :path, :permission, :add_group_owner) SENSITIVE = [] include Aws::Structure end |
#permission ⇒ String
The permission to access the device: read/only (`ro`) or read/write (`rw`).
Default: `ro`
2057 2058 2059 2060 2061 2062 2063 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2057 class LambdaDeviceMount < Struct.new( :path, :permission, :add_group_owner) SENSITIVE = [] include Aws::Structure end |