Class: Aws::GreengrassV2::Types::LambdaExecutionParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::LambdaExecutionParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
When making an API call, you may pass LambdaExecutionParameters data as a hash:
{
event_sources: [
{
topic: "TopicString", # required
type: "PUB_SUB", # required, accepts PUB_SUB, IOT_CORE
},
],
max_queue_size: 1,
max_instances_count: 1,
max_idle_time_in_seconds: 1,
timeout_in_seconds: 1,
status_timeout_in_seconds: 1,
pinned: false,
input_payload_encoding_type: "json", # accepts json, binary
exec_args: ["LambdaExecArg"],
environment_variables: {
"NonEmptyString" => "String",
},
linux_process_params: {
isolation_mode: "GreengrassContainer", # accepts GreengrassContainer, NoContainer
container_params: {
memory_size_in_kb: 1,
mount_ro_sysfs: false,
volumes: [
{
source_path: "FileSystemPath", # required
destination_path: "FileSystemPath", # required
permission: "ro", # accepts ro, rw
add_group_owner: false,
},
],
devices: [
{
path: "FileSystemPath", # required
permission: "ro", # accepts ro, rw
add_group_owner: false,
},
],
},
},
}
Contains parameters for a Lambda function that runs on IoT Greengrass.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#environment_variables ⇒ Hash<String,String>
The map of environment variables that are available to the Lambda function when it runs.
-
#event_sources ⇒ Array<Types::LambdaEventSource>
The list of event sources to which to subscribe to receive work messages.
-
#exec_args ⇒ Array<String>
The list of arguments to pass to the Lambda function when it runs.
-
#input_payload_encoding_type ⇒ String
The encoding type that the Lambda function supports.
-
#linux_process_params ⇒ Types::LambdaLinuxProcessParams
The parameters for the Linux process that contains the Lambda function.
-
#max_idle_time_in_seconds ⇒ Integer
The maximum amount of time in seconds that a non-pinned Lambda function can idle before the IoT Greengrass Core software stops its process.
-
#max_instances_count ⇒ Integer
The maximum number of instances that a non-pinned Lambda function can run at the same time.
-
#max_queue_size ⇒ Integer
The maximum size of the message queue for the Lambda function component.
-
#pinned ⇒ Boolean
Whether or not the Lambda function is pinned, or long-lived.
-
#status_timeout_in_seconds ⇒ Integer
The interval in seconds at which a pinned (also known as long-lived) Lambda function component sends status updates to the Lambda manager component.
-
#timeout_in_seconds ⇒ Integer
The maximum amount of time in seconds that the Lambda function can process a work item.
Instance Attribute Details
#environment_variables ⇒ Hash<String,String>
The map of environment variables that are available to the Lambda function when it runs.
2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2555 class LambdaExecutionParameters < Struct.new( :event_sources, :max_queue_size, :max_instances_count, :max_idle_time_in_seconds, :timeout_in_seconds, :status_timeout_in_seconds, :pinned, :input_payload_encoding_type, :exec_args, :environment_variables, :linux_process_params) SENSITIVE = [] include Aws::Structure end |
#event_sources ⇒ Array<Types::LambdaEventSource>
The list of event sources to which to subscribe to receive work messages. The Lambda function runs when it receives a message from an event source. You can subscribe this function to local publish/subscribe messages and Amazon Web Services IoT Core MQTT messages.
2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2555 class LambdaExecutionParameters < Struct.new( :event_sources, :max_queue_size, :max_instances_count, :max_idle_time_in_seconds, :timeout_in_seconds, :status_timeout_in_seconds, :pinned, :input_payload_encoding_type, :exec_args, :environment_variables, :linux_process_params) SENSITIVE = [] include Aws::Structure end |
#exec_args ⇒ Array<String>
The list of arguments to pass to the Lambda function when it runs.
2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2555 class LambdaExecutionParameters < Struct.new( :event_sources, :max_queue_size, :max_instances_count, :max_idle_time_in_seconds, :timeout_in_seconds, :status_timeout_in_seconds, :pinned, :input_payload_encoding_type, :exec_args, :environment_variables, :linux_process_params) SENSITIVE = [] include Aws::Structure end |
#input_payload_encoding_type ⇒ String
The encoding type that the Lambda function supports.
Default: `json`
2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2555 class LambdaExecutionParameters < Struct.new( :event_sources, :max_queue_size, :max_instances_count, :max_idle_time_in_seconds, :timeout_in_seconds, :status_timeout_in_seconds, :pinned, :input_payload_encoding_type, :exec_args, :environment_variables, :linux_process_params) SENSITIVE = [] include Aws::Structure end |
#linux_process_params ⇒ Types::LambdaLinuxProcessParams
The parameters for the Linux process that contains the Lambda function.
2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2555 class LambdaExecutionParameters < Struct.new( :event_sources, :max_queue_size, :max_instances_count, :max_idle_time_in_seconds, :timeout_in_seconds, :status_timeout_in_seconds, :pinned, :input_payload_encoding_type, :exec_args, :environment_variables, :linux_process_params) SENSITIVE = [] include Aws::Structure end |
#max_idle_time_in_seconds ⇒ Integer
The maximum amount of time in seconds that a non-pinned Lambda function can idle before the IoT Greengrass Core software stops its process.
2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2555 class LambdaExecutionParameters < Struct.new( :event_sources, :max_queue_size, :max_instances_count, :max_idle_time_in_seconds, :timeout_in_seconds, :status_timeout_in_seconds, :pinned, :input_payload_encoding_type, :exec_args, :environment_variables, :linux_process_params) SENSITIVE = [] include Aws::Structure end |
#max_instances_count ⇒ Integer
The maximum number of instances that a non-pinned Lambda function can run at the same time.
2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2555 class LambdaExecutionParameters < Struct.new( :event_sources, :max_queue_size, :max_instances_count, :max_idle_time_in_seconds, :timeout_in_seconds, :status_timeout_in_seconds, :pinned, :input_payload_encoding_type, :exec_args, :environment_variables, :linux_process_params) SENSITIVE = [] include Aws::Structure end |
#max_queue_size ⇒ Integer
The maximum size of the message queue for the Lambda function component. The IoT Greengrass core stores messages in a FIFO (first-in-first-out) queue until it can run the Lambda function to consume each message.
2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2555 class LambdaExecutionParameters < Struct.new( :event_sources, :max_queue_size, :max_instances_count, :max_idle_time_in_seconds, :timeout_in_seconds, :status_timeout_in_seconds, :pinned, :input_payload_encoding_type, :exec_args, :environment_variables, :linux_process_params) SENSITIVE = [] include Aws::Structure end |
#pinned ⇒ Boolean
Whether or not the Lambda function is pinned, or long-lived.
-
A pinned Lambda function starts when IoT Greengrass starts and keeps running in its own container.
-
A non-pinned Lambda function starts only when it receives a work item and exists after it idles for `maxIdleTimeInSeconds`. If the function has multiple work items, the IoT Greengrass Core software creates multiple instances of the function.
Default: `true`
2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2555 class LambdaExecutionParameters < Struct.new( :event_sources, :max_queue_size, :max_instances_count, :max_idle_time_in_seconds, :timeout_in_seconds, :status_timeout_in_seconds, :pinned, :input_payload_encoding_type, :exec_args, :environment_variables, :linux_process_params) SENSITIVE = [] include Aws::Structure end |
#status_timeout_in_seconds ⇒ Integer
The interval in seconds at which a pinned (also known as long-lived) Lambda function component sends status updates to the Lambda manager component.
2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2555 class LambdaExecutionParameters < Struct.new( :event_sources, :max_queue_size, :max_instances_count, :max_idle_time_in_seconds, :timeout_in_seconds, :status_timeout_in_seconds, :pinned, :input_payload_encoding_type, :exec_args, :environment_variables, :linux_process_params) SENSITIVE = [] include Aws::Structure end |
#timeout_in_seconds ⇒ Integer
The maximum amount of time in seconds that the Lambda function can process a work item.
2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2555 class LambdaExecutionParameters < Struct.new( :event_sources, :max_queue_size, :max_instances_count, :max_idle_time_in_seconds, :timeout_in_seconds, :status_timeout_in_seconds, :pinned, :input_payload_encoding_type, :exec_args, :environment_variables, :linux_process_params) SENSITIVE = [] include Aws::Structure end |