Class: Aws::GreengrassV2::Types::LambdaFunctionRecipeSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::LambdaFunctionRecipeSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
When making an API call, you may pass LambdaFunctionRecipeSource data as a hash:
{
lambda_arn: "LambdaFunctionARNWithVersionNumber", # required
component_name: "ComponentNameString",
component_version: "ComponentVersionString",
component_platforms: [
{
name: "NonEmptyString",
attributes: {
"NonEmptyString" => "NonEmptyString",
},
},
],
component_dependencies: {
"NonEmptyString" => {
version_requirement: "NonEmptyString",
dependency_type: "HARD", # accepts HARD, SOFT
},
},
component_lambda_parameters: {
event_sources: [
{
topic: "TopicString", # required
type: "PUB_SUB", # required, accepts PUB_SUB, IOT_CORE
},
],
max_queue_size: 1,
max_instances_count: 1,
max_idle_time_in_seconds: 1,
timeout_in_seconds: 1,
status_timeout_in_seconds: 1,
pinned: false,
input_payload_encoding_type: "json", # accepts json, binary
exec_args: ["LambdaExecArg"],
environment_variables: {
"NonEmptyString" => "String",
},
linux_process_params: {
isolation_mode: "GreengrassContainer", # accepts GreengrassContainer, NoContainer
container_params: {
memory_size_in_kb: 1,
mount_ro_sysfs: false,
volumes: [
{
source_path: "FileSystemPath", # required
destination_path: "FileSystemPath", # required
permission: "ro", # accepts ro, rw
add_group_owner: false,
},
],
devices: [
{
path: "FileSystemPath", # required
permission: "ro", # accepts ro, rw
add_group_owner: false,
},
],
},
},
},
}
Contains information about an Lambda function to import to create a component.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_dependencies ⇒ Hash<String,Types::ComponentDependencyRequirement>
The component versions on which this Lambda function component depends.
-
#component_lambda_parameters ⇒ Types::LambdaExecutionParameters
The system and runtime parameters for the Lambda function as it runs on the Greengrass core device.
-
#component_name ⇒ String
The name of the component.
-
#component_platforms ⇒ Array<Types::ComponentPlatform>
The platforms that the component version supports.
-
#component_version ⇒ String
The version of the component.
-
#lambda_arn ⇒ String
The [ARN] of the Lambda function.
Instance Attribute Details
#component_dependencies ⇒ Hash<String,Types::ComponentDependencyRequirement>
The component versions on which this Lambda function component depends.
2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2678 class LambdaFunctionRecipeSource < Struct.new( :lambda_arn, :component_name, :component_version, :component_platforms, :component_dependencies, :component_lambda_parameters) SENSITIVE = [] include Aws::Structure end |
#component_lambda_parameters ⇒ Types::LambdaExecutionParameters
The system and runtime parameters for the Lambda function as it runs on the Greengrass core device.
2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2678 class LambdaFunctionRecipeSource < Struct.new( :lambda_arn, :component_name, :component_version, :component_platforms, :component_dependencies, :component_lambda_parameters) SENSITIVE = [] include Aws::Structure end |
#component_name ⇒ String
The name of the component.
Defaults to the name of the Lambda function.
2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2678 class LambdaFunctionRecipeSource < Struct.new( :lambda_arn, :component_name, :component_version, :component_platforms, :component_dependencies, :component_lambda_parameters) SENSITIVE = [] include Aws::Structure end |
#component_platforms ⇒ Array<Types::ComponentPlatform>
The platforms that the component version supports.
2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2678 class LambdaFunctionRecipeSource < Struct.new( :lambda_arn, :component_name, :component_version, :component_platforms, :component_dependencies, :component_lambda_parameters) SENSITIVE = [] include Aws::Structure end |
#component_version ⇒ String
The version of the component.
Defaults to the version of the Lambda function as a semantic version. For example, if your function version is `3`, the component version becomes `3.0.0`.
2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2678 class LambdaFunctionRecipeSource < Struct.new( :lambda_arn, :component_name, :component_version, :component_platforms, :component_dependencies, :component_lambda_parameters) SENSITIVE = [] include Aws::Structure end |
#lambda_arn ⇒ String
The [ARN] of the Lambda function. The ARN must include the version of the function to import. You can't use version aliases like `$LATEST`.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2678 class LambdaFunctionRecipeSource < Struct.new( :lambda_arn, :component_name, :component_version, :component_platforms, :component_dependencies, :component_lambda_parameters) SENSITIVE = [] include Aws::Structure end |