Class: Aws::GreengrassV2::Types::LambdaVolumeMount
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::LambdaVolumeMount
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
When making an API call, you may pass LambdaVolumeMount data as a hash:
{
source_path: "FileSystemPath", # required
destination_path: "FileSystemPath", # required
permission: "ro", # accepts ro, rw
add_group_owner: false,
}
Contains information about a volume that Linux processes in a container can access. When you define a volume, the IoT Greengrass Core software mounts the source files to the destination inside the container.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add_group_owner ⇒ Boolean
Whether or not to add the IoT Greengrass user group as an owner of the volume.
-
#destination_path ⇒ String
The path to the logical volume in the file system.
-
#permission ⇒ String
The permission to access the volume: read/only (`ro`) or read/write (`rw`).
-
#source_path ⇒ String
The path to the physical volume in the file system.
Instance Attribute Details
#add_group_owner ⇒ Boolean
Whether or not to add the IoT Greengrass user group as an owner of the volume.
Default: `false`
2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2935 class LambdaVolumeMount < Struct.new( :source_path, :destination_path, :permission, :add_group_owner) SENSITIVE = [] include Aws::Structure end |
#destination_path ⇒ String
The path to the logical volume in the file system.
2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2935 class LambdaVolumeMount < Struct.new( :source_path, :destination_path, :permission, :add_group_owner) SENSITIVE = [] include Aws::Structure end |
#permission ⇒ String
The permission to access the volume: read/only (`ro`) or read/write (`rw`).
Default: `ro`
2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2935 class LambdaVolumeMount < Struct.new( :source_path, :destination_path, :permission, :add_group_owner) SENSITIVE = [] include Aws::Structure end |
#source_path ⇒ String
The path to the physical volume in the file system.
2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2935 class LambdaVolumeMount < Struct.new( :source_path, :destination_path, :permission, :add_group_owner) SENSITIVE = [] include Aws::Structure end |