Class: Aws::GreengrassV2::Types::ListDeploymentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-greengrassv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#history_filter ⇒ String

The filter for the list of deployments. Choose one of the following options:

  • ALL – The list includes all deployments.

  • LATEST_ONLY – The list includes only the latest revision of each deployment.

Default: LATEST_ONLY

Returns:

  • (String)


2613
2614
2615
2616
2617
2618
2619
2620
2621
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2613

class ListDeploymentsRequest < Struct.new(
  :target_arn,
  :history_filter,
  :parent_target_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to be returned per paginated request.

Default: 50

Returns:

  • (Integer)


2613
2614
2615
2616
2617
2618
2619
2620
2621
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2613

class ListDeploymentsRequest < Struct.new(
  :target_arn,
  :history_filter,
  :parent_target_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token to be used for the next set of paginated results.

Returns:

  • (String)


2613
2614
2615
2616
2617
2618
2619
2620
2621
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2613

class ListDeploymentsRequest < Struct.new(
  :target_arn,
  :history_filter,
  :parent_target_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#parent_target_arn ⇒ String

The parent deployment's target ARN within a subdeployment.

Returns:

  • (String)


2613
2614
2615
2616
2617
2618
2619
2620
2621
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2613

class ListDeploymentsRequest < Struct.new(
  :target_arn,
  :history_filter,
  :parent_target_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#target_arn ⇒ String

The ARN of the target IoT thing or thing group.

Returns:

  • (String)


2613
2614
2615
2616
2617
2618
2619
2620
2621
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2613

class ListDeploymentsRequest < Struct.new(
  :target_arn,
  :history_filter,
  :parent_target_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end