Class: Aws::GreengrassV2::Types::RequestAlreadyInProgressException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-greengrassv2/types.rb

Overview

The request is already in progress. This exception occurs when you use a client token for multiple requests while IoT Greengrass is still processing an earlier request that uses the same client token.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


3226
3227
3228
3229
3230
# File 'lib/aws-sdk-greengrassv2/types.rb', line 3226

class RequestAlreadyInProgressException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end