Class: Aws::GreengrassV2::Types::ResolveComponentCandidatesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-greengrassv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resolved_component_versionsArray<Types::ResolvedComponentVersion>

A list of components that meet the requirements that you specify in the request. This list includes each component's recipe that you can use to install the component.



3476
3477
3478
3479
3480
# File 'lib/aws-sdk-greengrassv2/types.rb', line 3476

class ResolveComponentCandidatesResponse < Struct.new(
  :resolved_component_versions)
  SENSITIVE = []
  include Aws::Structure
end