Class: Aws::GreengrassV2::Types::ResolvedComponentVersion
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::ResolvedComponentVersion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
Contains information about a component version that is compatible to run on a Greengrass core device.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The [ARN] of the component version.
-
#component_name ⇒ String
The name of the component.
-
#component_version ⇒ String
The version of the component.
-
#message ⇒ String
A message that communicates details about the vendor guidance state of the component version.
-
#recipe ⇒ String
The recipe of the component version.
-
#vendor_guidance ⇒ String
The vendor guidance state for the component version.
Instance Attribute Details
#arn ⇒ String
The [ARN] of the component version.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 3417 class ResolvedComponentVersion < Struct.new( :arn, :component_name, :component_version, :recipe, :vendor_guidance, :message) SENSITIVE = [] include Aws::Structure end |
#component_name ⇒ String
The name of the component.
3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 3417 class ResolvedComponentVersion < Struct.new( :arn, :component_name, :component_version, :recipe, :vendor_guidance, :message) SENSITIVE = [] include Aws::Structure end |
#component_version ⇒ String
The version of the component.
3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 3417 class ResolvedComponentVersion < Struct.new( :arn, :component_name, :component_version, :recipe, :vendor_guidance, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A message that communicates details about the vendor guidance state of the component version. This message communicates why a component version is discontinued or deleted.
3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 3417 class ResolvedComponentVersion < Struct.new( :arn, :component_name, :component_version, :recipe, :vendor_guidance, :message) SENSITIVE = [] include Aws::Structure end |
#recipe ⇒ String
The recipe of the component version.
3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 3417 class ResolvedComponentVersion < Struct.new( :arn, :component_name, :component_version, :recipe, :vendor_guidance, :message) SENSITIVE = [] include Aws::Structure end |
#vendor_guidance ⇒ String
The vendor guidance state for the component version. This state indicates whether the component version has any issues that you should consider before you deploy it. The vendor guidance state can be:
-
`ACTIVE` – This component version is available and recommended for use.
-
`DISCONTINUED` – This component version has been discontinued by its publisher. You can deploy this component version, but we recommend that you use a different version of this component.
-
`DELETED` – This component version has been deleted by its publisher, so you can't deploy it. If you have any existing deployments that specify this component version, those deployments will fail.
3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 3417 class ResolvedComponentVersion < Struct.new( :arn, :component_name, :component_version, :recipe, :vendor_guidance, :message) SENSITIVE = [] include Aws::Structure end |