Class: Aws::GreengrassV2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::GreengrassV2::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-greengrassv2/client.rb
Overview
An API client for GreengrassV2. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::GreengrassV2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_service_role_to_account(params = {}) ⇒ Types::AssociateServiceRoleToAccountResponse
Associates a Greengrass service role with IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region.
-
#batch_associate_client_device_with_core_device(params = {}) ⇒ Types::BatchAssociateClientDeviceWithCoreDeviceResponse
Associates a list of client devices with a core device.
-
#batch_disassociate_client_device_from_core_device(params = {}) ⇒ Types::BatchDisassociateClientDeviceFromCoreDeviceResponse
Disassociates a list of client devices from a core device.
-
#cancel_deployment(params = {}) ⇒ Types::CancelDeploymentResponse
Cancels a deployment.
-
#create_component_version(params = {}) ⇒ Types::CreateComponentVersionResponse
Creates a component.
-
#create_deployment(params = {}) ⇒ Types::CreateDeploymentResponse
Creates a continuous deployment for a target, which is a Greengrass core device or group of core devices.
-
#delete_component(params = {}) ⇒ Struct
Deletes a version of a component from IoT Greengrass.
-
#delete_core_device(params = {}) ⇒ Struct
Deletes a Greengrass core device, which is an IoT thing.
-
#delete_deployment(params = {}) ⇒ Struct
Deletes a deployment.
-
#describe_component(params = {}) ⇒ Types::DescribeComponentResponse
Retrieves metadata for a version of a component.
-
#disassociate_service_role_from_account(params = {}) ⇒ Types::DisassociateServiceRoleFromAccountResponse
Disassociates the Greengrass service role from IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region.
-
#get_component(params = {}) ⇒ Types::GetComponentResponse
Gets the recipe for a version of a component.
-
#get_component_version_artifact(params = {}) ⇒ Types::GetComponentVersionArtifactResponse
Gets the pre-signed URL to download a public or a Lambda component artifact.
-
#get_connectivity_info(params = {}) ⇒ Types::GetConnectivityInfoResponse
Retrieves connectivity information for a Greengrass core device.
-
#get_core_device(params = {}) ⇒ Types::GetCoreDeviceResponse
Retrieves metadata for a Greengrass core device.
-
#get_deployment(params = {}) ⇒ Types::GetDeploymentResponse
Gets a deployment.
-
#get_service_role_for_account(params = {}) ⇒ Types::GetServiceRoleForAccountResponse
Gets the service role associated with IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region.
-
#list_client_devices_associated_with_core_device(params = {}) ⇒ Types::ListClientDevicesAssociatedWithCoreDeviceResponse
Retrieves a paginated list of client devices that are associated with a core device.
-
#list_component_versions(params = {}) ⇒ Types::ListComponentVersionsResponse
Retrieves a paginated list of all versions for a component.
-
#list_components(params = {}) ⇒ Types::ListComponentsResponse
Retrieves a paginated list of component summaries.
-
#list_core_devices(params = {}) ⇒ Types::ListCoreDevicesResponse
Retrieves a paginated list of Greengrass core devices.
-
#list_deployments(params = {}) ⇒ Types::ListDeploymentsResponse
Retrieves a paginated list of deployments.
-
#list_effective_deployments(params = {}) ⇒ Types::ListEffectiveDeploymentsResponse
Retrieves a paginated list of deployment jobs that IoT Greengrass sends to Greengrass core devices.
-
#list_installed_components(params = {}) ⇒ Types::ListInstalledComponentsResponse
Retrieves a paginated list of the components that a Greengrass core device runs.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the list of tags for an IoT Greengrass resource.
-
#resolve_component_candidates(params = {}) ⇒ Types::ResolveComponentCandidatesResponse
Retrieves a list of components that meet the component, version, and platform requirements of a deployment.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to an IoT Greengrass resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from an IoT Greengrass resource.
-
#update_connectivity_info(params = {}) ⇒ Types::UpdateConnectivityInfoResponse
Updates connectivity information for a Greengrass core device.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
381 382 383 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 381 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2124 2125 2126 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 2124 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2127 2128 2129 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 2127 def errors_module Errors end |
Instance Method Details
#associate_service_role_to_account(params = {}) ⇒ Types::AssociateServiceRoleToAccountResponse
Associates a Greengrass service role with IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region. IoT Greengrass uses this role to verify the identity of client devices and manage core device connectivity information. The role must include the
- AWSGreengrassResourceAccessRolePolicy][1
-
managed policy or a custom
policy that defines equivalent permissions for the IoT Greengrass features that you use. For more information, see [Greengrass service role] in the *IoT Greengrass Version 2 Developer Guide*.
[1]: console.aws.amazon.com/iam/home#/policies/arn:awsiam::aws:policy/service-role/AWSGreengrassResourceAccessRolePolicy [2]: docs.aws.amazon.com/greengrass/v2/developerguide/greengrass-service-role.html
424 425 426 427 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 424 def associate_service_role_to_account(params = {}, = {}) req = build_request(:associate_service_role_to_account, params) req.send_request() end |
#batch_associate_client_device_with_core_device(params = {}) ⇒ Types::BatchAssociateClientDeviceWithCoreDeviceResponse
Associates a list of client devices with a core device. Use this API operation to specify which client devices can discover a core device through cloud discovery. With cloud discovery, client devices connect to IoT Greengrass to retrieve associated core devices’ connectivity information and certificates. For more information, see [Configure cloud discovery] in the *IoT Greengrass V2 Developer Guide*.
<note markdown=“1”> Client devices are local IoT devices that connect to and communicate with an IoT Greengrass core device over MQTT. You can connect client devices to a core device to sync MQTT messages and data to Amazon Web Services IoT Core and interact with client devices in Greengrass components. For more information, see [Interact with local IoT devices] in the *IoT Greengrass V2 Developer Guide*.
</note>
[1]: docs.aws.amazon.com/greengrass/v2/developerguide/configure-cloud-discovery.html [2]: docs.aws.amazon.com/greengrass/v2/developerguide/interact-with-local-iot-devices.html
482 483 484 485 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 482 def batch_associate_client_device_with_core_device(params = {}, = {}) req = build_request(:batch_associate_client_device_with_core_device, params) req.send_request() end |
#batch_disassociate_client_device_from_core_device(params = {}) ⇒ Types::BatchDisassociateClientDeviceFromCoreDeviceResponse
Disassociates a list of client devices from a core device. After you disassociate a client device from a core device, the client device won’t be able to use cloud discovery to retrieve the core device’s connectivity information and certificates.
524 525 526 527 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 524 def batch_disassociate_client_device_from_core_device(params = {}, = {}) req = build_request(:batch_disassociate_client_device_from_core_device, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 2102 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-greengrassv2' context[:gem_version] = '1.29.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_deployment(params = {}) ⇒ Types::CancelDeploymentResponse
Cancels a deployment. This operation cancels the deployment for devices that haven’t yet received it. If a device already received the deployment, this operation doesn’t change anything for that device.
555 556 557 558 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 555 def cancel_deployment(params = {}, = {}) req = build_request(:cancel_deployment, params) req.send_request() end |
#create_component_version(params = {}) ⇒ Types::CreateComponentVersionResponse
Creates a component. Components are software that run on Greengrass core devices. After you develop and test a component on your core device, you can use this operation to upload your component to IoT Greengrass. Then, you can deploy the component to other core devices.
You can use this operation to do the following:
-
**Create components from recipes**
Create a component from a recipe, which is a file that defines the component’s metadata, parameters, dependencies, lifecycle, artifacts, and platform capability. For more information, see [IoT Greengrass component recipe reference] in the *IoT Greengrass V2 Developer Guide*.
To create a component from a recipe, specify ‘inlineRecipe` when you call this operation.
-
**Create components from Lambda functions**
Create a component from an Lambda function that runs on IoT Greengrass. This creates a recipe and artifacts from the Lambda function’s deployment package. You can use this operation to migrate Lambda functions from IoT Greengrass V1 to IoT Greengrass V2.
This function only accepts Lambda functions that use the following runtimes:
-
Python 2.7 – ‘python2.7`
-
Python 3.7 – ‘python3.7`
-
Python 3.8 – ‘python3.8`
-
Python 3.9 – ‘python3.9`
-
Java 8 – ‘java8`
-
Java 11 – ‘java11`
-
Node.js 10 – ‘nodejs10.x`
-
Node.js 12 – ‘nodejs12.x`
-
Node.js 14 – ‘nodejs14.x`
To create a component from a Lambda function, specify ‘lambdaFunction` when you call this operation.
<note markdown=“1”> IoT Greengrass currently supports Lambda functions on only Linux core devices.
</note> -
[1]: docs.aws.amazon.com/greengrass/v2/developerguide/component-recipe-reference.html
748 749 750 751 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 748 def create_component_version(params = {}, = {}) req = build_request(:create_component_version, params) req.send_request() end |
#create_deployment(params = {}) ⇒ Types::CreateDeploymentResponse
Creates a continuous deployment for a target, which is a Greengrass core device or group of core devices. When you add a new core device to a group of core devices that has a deployment, IoT Greengrass deploys that group’s deployment to the new device.
You can define one deployment for each target. When you create a new deployment for a target that has an existing deployment, you replace the previous deployment. IoT Greengrass applies the new deployment to the target devices.
Every deployment has a revision number that indicates how many deployment revisions you define for a target. Use this operation to create a new revision of an existing deployment.
For more information, see the [Create deployments] in the *IoT Greengrass V2 Developer Guide*.
[1]: docs.aws.amazon.com/greengrass/v2/developerguide/create-deployments.html
909 910 911 912 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 909 def create_deployment(params = {}, = {}) req = build_request(:create_deployment, params) req.send_request() end |
#delete_component(params = {}) ⇒ Struct
Deletes a version of a component from IoT Greengrass.
<note markdown=“1”> This operation deletes the component’s recipe and artifacts. As a result, deployments that refer to this component version will fail. If you have deployments that use this component version, you can remove the component from the deployment or update the deployment to use a valid version.
</note>
943 944 945 946 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 943 def delete_component(params = {}, = {}) req = build_request(:delete_component, params) req.send_request() end |
#delete_core_device(params = {}) ⇒ Struct
Deletes a Greengrass core device, which is an IoT thing. This operation removes the core device from the list of core devices. This operation doesn’t delete the IoT thing. For more information about how to delete the IoT thing, see [DeleteThing] in the *IoT API Reference*.
[1]: docs.aws.amazon.com/iot/latest/apireference/API_DeleteThing.html
973 974 975 976 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 973 def delete_core_device(params = {}, = {}) req = build_request(:delete_core_device, params) req.send_request() end |
#delete_deployment(params = {}) ⇒ Struct
Deletes a deployment. To delete an active deployment, you must first cancel it. For more information, see [CancelDeployment].
Deleting a deployment doesn’t affect core devices that run that deployment, because core devices store the deployment’s configuration on the device. Additionally, core devices can roll back to a previous deployment that has been deleted.
[1]: docs.aws.amazon.com/iot/latest/apireference/API_CancelDeployment.html
1005 1006 1007 1008 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 1005 def delete_deployment(params = {}, = {}) req = build_request(:delete_deployment, params) req.send_request() end |
#describe_component(params = {}) ⇒ Types::DescribeComponentResponse
Retrieves metadata for a version of a component.
1062 1063 1064 1065 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 1062 def describe_component(params = {}, = {}) req = build_request(:describe_component, params) req.send_request() end |
#disassociate_service_role_from_account(params = {}) ⇒ Types::DisassociateServiceRoleFromAccountResponse
Disassociates the Greengrass service role from IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region. Without a service role, IoT Greengrass can’t verify the identity of client devices or manage core device connectivity information. For more information, see [Greengrass service role] in the *IoT Greengrass Version 2 Developer Guide*.
[1]: docs.aws.amazon.com/greengrass/v2/developerguide/greengrass-service-role.html
1090 1091 1092 1093 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 1090 def disassociate_service_role_from_account(params = {}, = {}) req = build_request(:disassociate_service_role_from_account, params) req.send_request() end |
#get_component(params = {}) ⇒ Types::GetComponentResponse
Gets the recipe for a version of a component.
1131 1132 1133 1134 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 1131 def get_component(params = {}, = {}) req = build_request(:get_component, params) req.send_request() end |
#get_component_version_artifact(params = {}) ⇒ Types::GetComponentVersionArtifactResponse
Gets the pre-signed URL to download a public or a Lambda component artifact. Core devices call this operation to identify the URL that they can use to download an artifact to install.
1180 1181 1182 1183 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 1180 def get_component_version_artifact(params = {}, = {}) req = build_request(:get_component_version_artifact, params) req.send_request() end |
#get_connectivity_info(params = {}) ⇒ Types::GetConnectivityInfoResponse
Retrieves connectivity information for a Greengrass core device.
Connectivity information includes endpoints and ports where client devices can connect to an MQTT broker on the core device. When a client device calls the [IoT Greengrass discovery API], IoT Greengrass returns connectivity information for all of the core devices where the client device can connect. For more information, see
- Connect client devices to core devices][2
-
in the *IoT Greengrass
Version 2 Developer Guide*.
[1]: docs.aws.amazon.com/greengrass/v2/developerguide/greengrass-discover-api.html [2]: docs.aws.amazon.com/greengrass/v2/developerguide/connect-client-devices.html
1227 1228 1229 1230 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 1227 def get_connectivity_info(params = {}, = {}) req = build_request(:get_connectivity_info, params) req.send_request() end |
#get_core_device(params = {}) ⇒ Types::GetCoreDeviceResponse
Retrieves metadata for a Greengrass core device.
<note markdown=“1”> IoT Greengrass relies on individual devices to send status updates to the Amazon Web Services Cloud. If the IoT Greengrass Core software isn’t running on the device, or if device isn’t connected to the Amazon Web Services Cloud, then the reported status of that device might not reflect its current status. The status timestamp indicates when the device status was last updated.
Core devices send status updates at the following times:
* When the IoT Greengrass Core software starts
-
When the core device receives a deployment from the Amazon Web Services Cloud
-
When the status of any component on the core device becomes ‘BROKEN`
-
At a [regular interval that you can configure], which defaults to 24 hours
-
For IoT Greengrass Core v2.7.0, the core device sends status updates upon local deployment and cloud deployment
</note>
1296 1297 1298 1299 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 1296 def get_core_device(params = {}, = {}) req = build_request(:get_core_device, params) req.send_request() end |
#get_deployment(params = {}) ⇒ Types::GetDeploymentResponse
Gets a deployment. Deployments define the components that run on Greengrass core devices.
1373 1374 1375 1376 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 1373 def get_deployment(params = {}, = {}) req = build_request(:get_deployment, params) req.send_request() end |
#get_service_role_for_account(params = {}) ⇒ Types::GetServiceRoleForAccountResponse
Gets the service role associated with IoT Greengrass for your Amazon Web Services account in this Amazon Web Services Region. IoT Greengrass uses this role to verify the identity of client devices and manage core device connectivity information. For more information, see
- Greengrass service role][1
-
in the *IoT Greengrass Version 2
Developer Guide*.
[1]: docs.aws.amazon.com/greengrass/v2/developerguide/greengrass-service-role.html
1403 1404 1405 1406 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 1403 def get_service_role_for_account(params = {}, = {}) req = build_request(:get_service_role_for_account, params) req.send_request() end |
#list_client_devices_associated_with_core_device(params = {}) ⇒ Types::ListClientDevicesAssociatedWithCoreDeviceResponse
Retrieves a paginated list of client devices that are associated with a core device.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1446 1447 1448 1449 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 1446 def list_client_devices_associated_with_core_device(params = {}, = {}) req = build_request(:list_client_devices_associated_with_core_device, params) req.send_request() end |
#list_component_versions(params = {}) ⇒ Types::ListComponentVersionsResponse
Retrieves a paginated list of all versions for a component. Greater versions are listed first.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1494 1495 1496 1497 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 1494 def list_component_versions(params = {}, = {}) req = build_request(:list_component_versions, params) req.send_request() end |
#list_components(params = {}) ⇒ Types::ListComponentsResponse
Retrieves a paginated list of component summaries. This list includes components that you have permission to view.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1548 1549 1550 1551 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 1548 def list_components(params = {}, = {}) req = build_request(:list_components, params) req.send_request() end |
#list_core_devices(params = {}) ⇒ Types::ListCoreDevicesResponse
Retrieves a paginated list of Greengrass core devices.
<note markdown=“1”> IoT Greengrass relies on individual devices to send status updates to the Amazon Web Services Cloud. If the IoT Greengrass Core software isn’t running on the device, or if device isn’t connected to the Amazon Web Services Cloud, then the reported status of that device might not reflect its current status. The status timestamp indicates when the device status was last updated.
Core devices send status updates at the following times:
* When the IoT Greengrass Core software starts
-
When the core device receives a deployment from the Amazon Web Services Cloud
-
When the status of any component on the core device becomes ‘BROKEN`
-
At a [regular interval that you can configure], which defaults to 24 hours
-
For IoT Greengrass Core v2.7.0, the core device sends status updates upon local deployment and cloud deployment
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1639 1640 1641 1642 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 1639 def list_core_devices(params = {}, = {}) req = build_request(:list_core_devices, params) req.send_request() end |
#list_deployments(params = {}) ⇒ Types::ListDeploymentsResponse
Retrieves a paginated list of deployments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1711 1712 1713 1714 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 1711 def list_deployments(params = {}, = {}) req = build_request(:list_deployments, params) req.send_request() end |
#list_effective_deployments(params = {}) ⇒ Types::ListEffectiveDeploymentsResponse
Retrieves a paginated list of deployment jobs that IoT Greengrass sends to Greengrass core devices.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1766 1767 1768 1769 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 1766 def list_effective_deployments(params = {}, = {}) req = build_request(:list_effective_deployments, params) req.send_request() end |
#list_installed_components(params = {}) ⇒ Types::ListInstalledComponentsResponse
Retrieves a paginated list of the components that a Greengrass core device runs. By default, this list doesn’t include components that are deployed as dependencies of other components. To include dependencies in the response, set the ‘topologyFilter` parameter to `ALL`.
<note markdown=“1”> IoT Greengrass relies on individual devices to send status updates to the Amazon Web Services Cloud. If the IoT Greengrass Core software isn’t running on the device, or if device isn’t connected to the Amazon Web Services Cloud, then the reported status of that device might not reflect its current status. The status timestamp indicates when the device status was last updated.
Core devices send status updates at the following times:
* When the IoT Greengrass Core software starts
-
When the core device receives a deployment from the Amazon Web Services Cloud
-
When the status of any component on the core device becomes ‘BROKEN`
-
At a [regular interval that you can configure], which defaults to 24 hours
-
For IoT Greengrass Core v2.7.0, the core device sends status updates upon local deployment and cloud deployment
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1863 1864 1865 1866 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 1863 def list_installed_components(params = {}, = {}) req = build_request(:list_installed_components, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the list of tags for an IoT Greengrass resource.
1896 1897 1898 1899 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 1896 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#resolve_component_candidates(params = {}) ⇒ Types::ResolveComponentCandidatesResponse
Retrieves a list of components that meet the component, version, and platform requirements of a deployment. Greengrass core devices call this operation when they receive a deployment to identify the components to install.
This operation identifies components that meet all dependency requirements for a deployment. If the requirements conflict, then this operation returns an error and the deployment fails. For example, this occurs if component ‘A` requires version `>2.0.0` and component `B` requires version `<2.0.0` of a component dependency.
When you specify the component candidates to resolve, IoT Greengrass compares each component’s digest from the core device with the component’s digest in the Amazon Web Services Cloud. If the digests don’t match, then IoT Greengrass specifies to use the version from the Amazon Web Services Cloud.
To use this operation, you must use the data plane API endpoint and authenticate with an IoT device certificate. For more information, see [IoT Greengrass endpoints and quotas].
1970 1971 1972 1973 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 1970 def resolve_component_candidates(params = {}, = {}) req = build_request(:resolve_component_candidates, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to an IoT Greengrass resource. If a tag already exists for the resource, this operation updates the tag’s value.
2009 2010 2011 2012 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 2009 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag from an IoT Greengrass resource.
2039 2040 2041 2042 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 2039 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_connectivity_info(params = {}) ⇒ Types::UpdateConnectivityInfoResponse
Updates connectivity information for a Greengrass core device.
Connectivity information includes endpoints and ports where client devices can connect to an MQTT broker on the core device. When a client device calls the [IoT Greengrass discovery API], IoT Greengrass returns connectivity information for all of the core devices where the client device can connect. For more information, see
- Connect client devices to core devices][2
-
in the *IoT Greengrass
Version 2 Developer Guide*.
[1]: docs.aws.amazon.com/greengrass/v2/developerguide/greengrass-discover-api.html [2]: docs.aws.amazon.com/greengrass/v2/developerguide/connect-client-devices.html
2093 2094 2095 2096 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 2093 def update_connectivity_info(params = {}, = {}) req = build_request(:update_connectivity_info, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2117 2118 2119 |
# File 'lib/aws-sdk-greengrassv2/client.rb', line 2117 def waiter_names [] end |