Class: Aws::GreengrassV2::Types::CloudComponentStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-greengrassv2/types.rb

Overview

Contains the status of a component in the IoT Greengrass service.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#component_stateString

The state of the component.

Returns:

  • (String)


278
279
280
281
282
283
284
# File 'lib/aws-sdk-greengrassv2/types.rb', line 278

class CloudComponentStatus < Struct.new(
  :component_state,
  :message,
  :errors)
  SENSITIVE = []
  include Aws::Structure
end

#errorsHash<String,String>

A dictionary of errors that communicate why the component is in an error state. For example, if IoT Greengrass can't access an artifact for the component, then `errors` contains the artifact's URI as a key, and the error message as the value for that key.

Returns:

  • (Hash<String,String>)


278
279
280
281
282
283
284
# File 'lib/aws-sdk-greengrassv2/types.rb', line 278

class CloudComponentStatus < Struct.new(
  :component_state,
  :message,
  :errors)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A message that communicates details, such as errors, about the status of the component.

Returns:

  • (String)


278
279
280
281
282
283
284
# File 'lib/aws-sdk-greengrassv2/types.rb', line 278

class CloudComponentStatus < Struct.new(
  :component_state,
  :message,
  :errors)
  SENSITIVE = []
  include Aws::Structure
end