Class: Aws::GreengrassV2::Types::ComponentCandidate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-greengrassv2/types.rb

Overview

Note:

When making an API call, you may pass ComponentCandidate data as a hash:

{
  component_name: "ComponentNameString",
  component_version: "ComponentVersionString",
  version_requirements: {
    "NonEmptyString" => "NonEmptyString",
  },
}

Contains information about a component that is a candidate to deploy to a Greengrass core device.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#component_nameString

The name of the component.

Returns:

  • (String)


351
352
353
354
355
356
357
# File 'lib/aws-sdk-greengrassv2/types.rb', line 351

class ComponentCandidate < Struct.new(
  :component_name,
  :component_version,
  :version_requirements)
  SENSITIVE = []
  include Aws::Structure
end

#component_versionString

The version of the component.

Returns:

  • (String)


351
352
353
354
355
356
357
# File 'lib/aws-sdk-greengrassv2/types.rb', line 351

class ComponentCandidate < Struct.new(
  :component_name,
  :component_version,
  :version_requirements)
  SENSITIVE = []
  include Aws::Structure
end

#version_requirementsHash<String,String>

The version requirements for the component's dependencies. Greengrass core devices get the version requirements from component recipes.

IoT Greengrass V2 uses semantic version constraints. For more information, see [Semantic Versioning].

[1]: semver.org/

Returns:

  • (Hash<String,String>)


351
352
353
354
355
356
357
# File 'lib/aws-sdk-greengrassv2/types.rb', line 351

class ComponentCandidate < Struct.new(
  :component_name,
  :component_version,
  :version_requirements)
  SENSITIVE = []
  include Aws::Structure
end