Class: Aws::GreengrassV2::Types::ConnectivityInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-greengrassv2/types.rb

Overview

Note:

When making an API call, you may pass ConnectivityInfo data as a hash:

{
  id: "String",
  host_address: "String",
  port_number: 1,
  metadata: "String",
}

Contains information about an endpoint and port where client devices can connect to an MQTT broker on a Greengrass core device.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#host_addressString

The IP address or DNS address where client devices can connect to an MQTT broker on the Greengrass core device.

Returns:

  • (String)


774
775
776
777
778
779
780
781
# File 'lib/aws-sdk-greengrassv2/types.rb', line 774

class ConnectivityInfo < Struct.new(
  :id,
  :host_address,
  :port_number,
  :metadata)
  SENSITIVE = []
  include Aws::Structure
end

#idString

An ID for the connectivity information.

Returns:

  • (String)


774
775
776
777
778
779
780
781
# File 'lib/aws-sdk-greengrassv2/types.rb', line 774

class ConnectivityInfo < Struct.new(
  :id,
  :host_address,
  :port_number,
  :metadata)
  SENSITIVE = []
  include Aws::Structure
end

#metadataString

Additional metadata to provide to client devices that connect to this core device.

Returns:

  • (String)


774
775
776
777
778
779
780
781
# File 'lib/aws-sdk-greengrassv2/types.rb', line 774

class ConnectivityInfo < Struct.new(
  :id,
  :host_address,
  :port_number,
  :metadata)
  SENSITIVE = []
  include Aws::Structure
end

#port_numberInteger

The port where the MQTT broker operates on the core device. This port is typically 8883, which is the default port for the MQTT broker component that runs on core devices.

Returns:

  • (Integer)


774
775
776
777
778
779
780
781
# File 'lib/aws-sdk-greengrassv2/types.rb', line 774

class ConnectivityInfo < Struct.new(
  :id,
  :host_address,
  :port_number,
  :metadata)
  SENSITIVE = []
  include Aws::Structure
end