Class: Aws::GreengrassV2::Types::DeploymentComponentUpdatePolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-greengrassv2/types.rb

Overview

Note:

When making an API call, you may pass DeploymentComponentUpdatePolicy data as a hash:

{
  timeout_in_seconds: 1,
  action: "NOTIFY_COMPONENTS", # accepts NOTIFY_COMPONENTS, SKIP_NOTIFY_COMPONENTS
}

Contains information about a deployment's policy that defines when components are safe to update.

Each component on a device can report whether or not it's ready to update. After a component and its dependencies are ready, they can apply the update in the deployment. You can configure whether or not the deployment notifies components of an update and waits for a response. You specify the amount of time each component has to respond to the update notification.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

Whether or not to notify components and wait for components to become safe to update. Choose from the following options:

  • `NOTIFY_COMPONENTS` – The deployment notifies each component before it stops and updates that component. Components can use the

    SubscribeToComponentUpdates][1

    IPC operation to receive these

    notifications. Then, components can respond with the

    DeferComponentUpdate][2

    IPC operation. For more information, see

    Create deployments][3

    in the *IoT Greengrass V2 Developer

    Guide*.

  • `SKIP_NOTIFY_COMPONENTS` – The deployment doesn't notify components or wait for them to be safe to update.

Default: `NOTIFY_COMPONENTS`

[1]: docs.aws.amazon.com/greengrass/v2/developerguide/interprocess-communication.html#ipc-operation-subscribetocomponentupdates [2]: docs.aws.amazon.com/greengrass/v2/developerguide/interprocess-communication.html#ipc-operation-defercomponentupdate [3]: docs.aws.amazon.com/greengrass/v2/developerguide/create-deployments.html

Returns:

  • (String)


1277
1278
1279
1280
1281
1282
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1277

class DeploymentComponentUpdatePolicy < Struct.new(
  :timeout_in_seconds,
  :action)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_in_secondsInteger

The amount of time in seconds that each component on a device has to report that it's safe to update. If the component waits for longer than this timeout, then the deployment proceeds on the device.

Default: `60`

Returns:

  • (Integer)


1277
1278
1279
1280
1281
1282
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1277

class DeploymentComponentUpdatePolicy < Struct.new(
  :timeout_in_seconds,
  :action)
  SENSITIVE = []
  include Aws::Structure
end