Class: Aws::GreengrassV2::Types::EffectiveDeployment
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::EffectiveDeployment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
Contains information about a deployment job that IoT Greengrass sends to a Greengrass core device.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#core_device_execution_status ⇒ String
The status of the deployment job on the Greengrass core device.
-
#creation_timestamp ⇒ Time
The time at which the deployment was created, expressed in ISO 8601 format.
-
#deployment_id ⇒ String
The ID of the deployment.
-
#deployment_name ⇒ String
The name of the deployment.
-
#description ⇒ String
The description of the deployment job.
-
#iot_job_arn ⇒ String
The [ARN] of the IoT job that applies the deployment to target devices.
-
#iot_job_id ⇒ String
The ID of the IoT job that applies the deployment to target devices.
-
#modified_timestamp ⇒ Time
The time at which the deployment job was last modified, expressed in ISO 8601 format.
-
#reason ⇒ String
The reason code for the update, if the job was updated.
-
#target_arn ⇒ String
The [ARN] of the target IoT thing or thing group.
Instance Attribute Details
#core_device_execution_status ⇒ String
The status of the deployment job on the Greengrass core device.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1648 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp) SENSITIVE = [] include Aws::Structure end |
#creation_timestamp ⇒ Time
The time at which the deployment was created, expressed in ISO 8601 format.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1648 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp) SENSITIVE = [] include Aws::Structure end |
#deployment_id ⇒ String
The ID of the deployment.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1648 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp) SENSITIVE = [] include Aws::Structure end |
#deployment_name ⇒ String
The name of the deployment.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1648 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the deployment job.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1648 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp) SENSITIVE = [] include Aws::Structure end |
#iot_job_arn ⇒ String
The [ARN] of the IoT job that applies the deployment to target devices.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1648 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp) SENSITIVE = [] include Aws::Structure end |
#iot_job_id ⇒ String
The ID of the IoT job that applies the deployment to target devices.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1648 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp) SENSITIVE = [] include Aws::Structure end |
#modified_timestamp ⇒ Time
The time at which the deployment job was last modified, expressed in ISO 8601 format.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1648 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
The reason code for the update, if the job was updated.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1648 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The [ARN] of the target IoT thing or thing group.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1648 class EffectiveDeployment < Struct.new( :deployment_id, :deployment_name, :iot_job_id, :iot_job_arn, :description, :target_arn, :core_device_execution_status, :reason, :creation_timestamp, :modified_timestamp) SENSITIVE = [] include Aws::Structure end |