Class: Aws::GreengrassV2::Types::GetComponentVersionArtifactRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::GetComponentVersionArtifactRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The [ARN] of the component version.
-
#artifact_name ⇒ String
The name of the artifact.
Instance Attribute Details
#arn ⇒ String
The [ARN] of the component version. Specify the ARN of a public or a Lambda component version.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
1490 1491 1492 1493 1494 1495 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1490 class GetComponentVersionArtifactRequest < Struct.new( :arn, :artifact_name) SENSITIVE = [] include Aws::Structure end |
#artifact_name ⇒ String
The name of the artifact.
You can use the [GetComponent] operation to download the component recipe, which includes the URI of the artifact. The artifact name is the section of the URI after the scheme. For example, in the artifact URI `greengrass:SomeArtifact.zip`, the artifact name is `SomeArtifact.zip`.
[1]: docs.aws.amazon.com/greengrass/v2/APIReference/API_GetComponent.html
1490 1491 1492 1493 1494 1495 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 1490 class GetComponentVersionArtifactRequest < Struct.new( :arn, :artifact_name) SENSITIVE = [] include Aws::Structure end |