Class: Aws::GreengrassV2::Types::GetDeploymentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::GetDeploymentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#components ⇒ Hash<String,Types::ComponentDeploymentSpecification>
The components to deploy.
-
#creation_timestamp ⇒ Time
The time at which the deployment was created, expressed in ISO 8601 format.
-
#deployment_id ⇒ String
The ID of the deployment.
-
#deployment_name ⇒ String
The name of the deployment.
-
#deployment_policies ⇒ Types::DeploymentPolicies
The deployment policies for the deployment.
-
#deployment_status ⇒ String
The status of the deployment.
-
#iot_job_arn ⇒ String
The [ARN] of the IoT job that applies the deployment to target devices.
-
#iot_job_configuration ⇒ Types::DeploymentIoTJobConfiguration
The job configuration for the deployment configuration.
-
#iot_job_id ⇒ String
The ID of the IoT job that applies the deployment to target devices.
-
#is_latest_for_target ⇒ Boolean
Whether or not the deployment is the latest revision for its target.
-
#parent_target_arn ⇒ String
The parent deployment's target [ARN] within a subdeployment.
-
#revision_id ⇒ String
The revision number of the deployment.
-
#tags ⇒ Hash<String,String>
A list of key-value pairs that contain metadata for the resource.
-
#target_arn ⇒ String
The [ARN] of the target IoT thing or thing group.
Instance Attribute Details
#components ⇒ Hash<String,Types::ComponentDeploymentSpecification>
The components to deploy. This is a dictionary, where each key is the name of a component, and each key's value is the version and configuration to deploy for that component.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2099 class GetDeploymentResponse < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :deployment_status, :iot_job_id, :iot_job_arn, :components, :deployment_policies, :iot_job_configuration, :creation_timestamp, :is_latest_for_target, :parent_target_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_timestamp ⇒ Time
The time at which the deployment was created, expressed in ISO 8601 format.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2099 class GetDeploymentResponse < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :deployment_status, :iot_job_id, :iot_job_arn, :components, :deployment_policies, :iot_job_configuration, :creation_timestamp, :is_latest_for_target, :parent_target_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#deployment_id ⇒ String
The ID of the deployment.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2099 class GetDeploymentResponse < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :deployment_status, :iot_job_id, :iot_job_arn, :components, :deployment_policies, :iot_job_configuration, :creation_timestamp, :is_latest_for_target, :parent_target_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#deployment_name ⇒ String
The name of the deployment.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2099 class GetDeploymentResponse < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :deployment_status, :iot_job_id, :iot_job_arn, :components, :deployment_policies, :iot_job_configuration, :creation_timestamp, :is_latest_for_target, :parent_target_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#deployment_policies ⇒ Types::DeploymentPolicies
The deployment policies for the deployment. These policies define how the deployment updates components and handles failure.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2099 class GetDeploymentResponse < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :deployment_status, :iot_job_id, :iot_job_arn, :components, :deployment_policies, :iot_job_configuration, :creation_timestamp, :is_latest_for_target, :parent_target_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#deployment_status ⇒ String
The status of the deployment.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2099 class GetDeploymentResponse < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :deployment_status, :iot_job_id, :iot_job_arn, :components, :deployment_policies, :iot_job_configuration, :creation_timestamp, :is_latest_for_target, :parent_target_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#iot_job_arn ⇒ String
The [ARN] of the IoT job that applies the deployment to target devices.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2099 class GetDeploymentResponse < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :deployment_status, :iot_job_id, :iot_job_arn, :components, :deployment_policies, :iot_job_configuration, :creation_timestamp, :is_latest_for_target, :parent_target_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#iot_job_configuration ⇒ Types::DeploymentIoTJobConfiguration
The job configuration for the deployment configuration. The job configuration specifies the rollout, timeout, and stop configurations for the deployment configuration.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2099 class GetDeploymentResponse < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :deployment_status, :iot_job_id, :iot_job_arn, :components, :deployment_policies, :iot_job_configuration, :creation_timestamp, :is_latest_for_target, :parent_target_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#iot_job_id ⇒ String
The ID of the IoT job that applies the deployment to target devices.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2099 class GetDeploymentResponse < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :deployment_status, :iot_job_id, :iot_job_arn, :components, :deployment_policies, :iot_job_configuration, :creation_timestamp, :is_latest_for_target, :parent_target_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#is_latest_for_target ⇒ Boolean
Whether or not the deployment is the latest revision for its target.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2099 class GetDeploymentResponse < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :deployment_status, :iot_job_id, :iot_job_arn, :components, :deployment_policies, :iot_job_configuration, :creation_timestamp, :is_latest_for_target, :parent_target_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#parent_target_arn ⇒ String
The parent deployment's target [ARN] within a subdeployment.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2099 class GetDeploymentResponse < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :deployment_status, :iot_job_id, :iot_job_arn, :components, :deployment_policies, :iot_job_configuration, :creation_timestamp, :is_latest_for_target, :parent_target_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
The revision number of the deployment.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2099 class GetDeploymentResponse < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :deployment_status, :iot_job_id, :iot_job_arn, :components, :deployment_policies, :iot_job_configuration, :creation_timestamp, :is_latest_for_target, :parent_target_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of key-value pairs that contain metadata for the resource. For more information, see [Tag your resources] in the *IoT Greengrass V2 Developer Guide*.
[1]: docs.aws.amazon.com/greengrass/v2/developerguide/tag-resources.html
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2099 class GetDeploymentResponse < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :deployment_status, :iot_job_id, :iot_job_arn, :components, :deployment_policies, :iot_job_configuration, :creation_timestamp, :is_latest_for_target, :parent_target_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The [ARN] of the target IoT thing or thing group.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2099 class GetDeploymentResponse < Struct.new( :target_arn, :revision_id, :deployment_id, :deployment_name, :deployment_status, :iot_job_id, :iot_job_arn, :components, :deployment_policies, :iot_job_configuration, :creation_timestamp, :is_latest_for_target, :parent_target_arn, :tags) SENSITIVE = [] include Aws::Structure end |