Class: Aws::GreengrassV2::Types::GetDeploymentResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-greengrassv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#componentsHash<String,Types::ComponentDeploymentSpecification>

The components to deploy. This is a dictionary, where each key is the name of a component, and each key's value is the version and configuration to deploy for that component.

Returns:



2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2070

class GetDeploymentResponse < Struct.new(
  :target_arn,
  :revision_id,
  :deployment_id,
  :deployment_name,
  :deployment_status,
  :iot_job_id,
  :iot_job_arn,
  :components,
  :deployment_policies,
  :iot_job_configuration,
  :creation_timestamp,
  :is_latest_for_target,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timestampTime

The time at which the deployment was created, expressed in ISO 8601 format.

Returns:

  • (Time)


2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2070

class GetDeploymentResponse < Struct.new(
  :target_arn,
  :revision_id,
  :deployment_id,
  :deployment_name,
  :deployment_status,
  :iot_job_id,
  :iot_job_arn,
  :components,
  :deployment_policies,
  :iot_job_configuration,
  :creation_timestamp,
  :is_latest_for_target,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_idString

The ID of the deployment.

Returns:

  • (String)


2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2070

class GetDeploymentResponse < Struct.new(
  :target_arn,
  :revision_id,
  :deployment_id,
  :deployment_name,
  :deployment_status,
  :iot_job_id,
  :iot_job_arn,
  :components,
  :deployment_policies,
  :iot_job_configuration,
  :creation_timestamp,
  :is_latest_for_target,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_nameString

The name of the deployment.

Returns:

  • (String)


2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2070

class GetDeploymentResponse < Struct.new(
  :target_arn,
  :revision_id,
  :deployment_id,
  :deployment_name,
  :deployment_status,
  :iot_job_id,
  :iot_job_arn,
  :components,
  :deployment_policies,
  :iot_job_configuration,
  :creation_timestamp,
  :is_latest_for_target,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_policiesTypes::DeploymentPolicies

The deployment policies for the deployment. These policies define how the deployment updates components and handles failure.



2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2070

class GetDeploymentResponse < Struct.new(
  :target_arn,
  :revision_id,
  :deployment_id,
  :deployment_name,
  :deployment_status,
  :iot_job_id,
  :iot_job_arn,
  :components,
  :deployment_policies,
  :iot_job_configuration,
  :creation_timestamp,
  :is_latest_for_target,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_statusString

The status of the deployment.

Returns:

  • (String)


2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2070

class GetDeploymentResponse < Struct.new(
  :target_arn,
  :revision_id,
  :deployment_id,
  :deployment_name,
  :deployment_status,
  :iot_job_id,
  :iot_job_arn,
  :components,
  :deployment_policies,
  :iot_job_configuration,
  :creation_timestamp,
  :is_latest_for_target,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#iot_job_arnString

The [ARN] of the IoT job that applies the deployment to target devices.

[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html

Returns:

  • (String)


2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2070

class GetDeploymentResponse < Struct.new(
  :target_arn,
  :revision_id,
  :deployment_id,
  :deployment_name,
  :deployment_status,
  :iot_job_id,
  :iot_job_arn,
  :components,
  :deployment_policies,
  :iot_job_configuration,
  :creation_timestamp,
  :is_latest_for_target,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#iot_job_configurationTypes::DeploymentIoTJobConfiguration

The job configuration for the deployment configuration. The job configuration specifies the rollout, timeout, and stop configurations for the deployment configuration.



2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2070

class GetDeploymentResponse < Struct.new(
  :target_arn,
  :revision_id,
  :deployment_id,
  :deployment_name,
  :deployment_status,
  :iot_job_id,
  :iot_job_arn,
  :components,
  :deployment_policies,
  :iot_job_configuration,
  :creation_timestamp,
  :is_latest_for_target,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#iot_job_idString

The ID of the IoT job that applies the deployment to target devices.

Returns:

  • (String)


2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2070

class GetDeploymentResponse < Struct.new(
  :target_arn,
  :revision_id,
  :deployment_id,
  :deployment_name,
  :deployment_status,
  :iot_job_id,
  :iot_job_arn,
  :components,
  :deployment_policies,
  :iot_job_configuration,
  :creation_timestamp,
  :is_latest_for_target,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#is_latest_for_targetBoolean

Whether or not the deployment is the latest revision for its target.

Returns:

  • (Boolean)


2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2070

class GetDeploymentResponse < Struct.new(
  :target_arn,
  :revision_id,
  :deployment_id,
  :deployment_name,
  :deployment_status,
  :iot_job_id,
  :iot_job_arn,
  :components,
  :deployment_policies,
  :iot_job_configuration,
  :creation_timestamp,
  :is_latest_for_target,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#revision_idString

The revision number of the deployment.

Returns:

  • (String)


2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2070

class GetDeploymentResponse < Struct.new(
  :target_arn,
  :revision_id,
  :deployment_id,
  :deployment_name,
  :deployment_status,
  :iot_job_id,
  :iot_job_arn,
  :components,
  :deployment_policies,
  :iot_job_configuration,
  :creation_timestamp,
  :is_latest_for_target,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A list of key-value pairs that contain metadata for the resource. For more information, see [Tag your resources] in the *IoT Greengrass V2 Developer Guide*.

[1]: docs.aws.amazon.com/greengrass/v2/developerguide/tag-resources.html

Returns:

  • (Hash<String,String>)


2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2070

class GetDeploymentResponse < Struct.new(
  :target_arn,
  :revision_id,
  :deployment_id,
  :deployment_name,
  :deployment_status,
  :iot_job_id,
  :iot_job_arn,
  :components,
  :deployment_policies,
  :iot_job_configuration,
  :creation_timestamp,
  :is_latest_for_target,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#target_arnString

The [ARN] of the target IoT thing or thing group.

[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html

Returns:

  • (String)


2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2070

class GetDeploymentResponse < Struct.new(
  :target_arn,
  :revision_id,
  :deployment_id,
  :deployment_name,
  :deployment_status,
  :iot_job_id,
  :iot_job_arn,
  :components,
  :deployment_policies,
  :iot_job_configuration,
  :creation_timestamp,
  :is_latest_for_target,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end