Class: Aws::GreengrassV2::Types::IoTJobAbortCriteria
- Inherits:
-
Struct
- Object
- Struct
- Aws::GreengrassV2::Types::IoTJobAbortCriteria
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-greengrassv2/types.rb
Overview
When making an API call, you may pass IoTJobAbortCriteria data as a hash:
{
failure_type: "FAILED", # required, accepts FAILED, REJECTED, TIMED_OUT, ALL
action: "CANCEL", # required, accepts CANCEL
threshold_percentage: 1.0, # required
min_number_of_executed_things: 1, # required
}
Contains criteria that define when and how to cancel a job.
The deployment stops if the following conditions are true:
-
The number of things that receive the deployment exceeds the `minNumberOfExecutedThings`.
-
The percentage of failures with type `failureType` exceeds the `thresholdPercentage`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action to perform when the criteria are met.
-
#failure_type ⇒ String
The type of job deployment failure that can cancel a job.
-
#min_number_of_executed_things ⇒ Integer
The minimum number of things that receive the configuration before the job can cancel.
-
#threshold_percentage ⇒ Float
The minimum percentage of `failureType` failures that occur before the job can cancel.
Instance Attribute Details
#action ⇒ String
The action to perform when the criteria are met.
2202 2203 2204 2205 2206 2207 2208 2209 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2202 class IoTJobAbortCriteria < Struct.new( :failure_type, :action, :threshold_percentage, :min_number_of_executed_things) SENSITIVE = [] include Aws::Structure end |
#failure_type ⇒ String
The type of job deployment failure that can cancel a job.
2202 2203 2204 2205 2206 2207 2208 2209 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2202 class IoTJobAbortCriteria < Struct.new( :failure_type, :action, :threshold_percentage, :min_number_of_executed_things) SENSITIVE = [] include Aws::Structure end |
#min_number_of_executed_things ⇒ Integer
The minimum number of things that receive the configuration before the job can cancel.
2202 2203 2204 2205 2206 2207 2208 2209 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2202 class IoTJobAbortCriteria < Struct.new( :failure_type, :action, :threshold_percentage, :min_number_of_executed_things) SENSITIVE = [] include Aws::Structure end |
#threshold_percentage ⇒ Float
The minimum percentage of `failureType` failures that occur before the job can cancel.
This parameter supports up to two digits after the decimal (for example, you can specify `10.9` or `10.99`, but not `10.999`).
2202 2203 2204 2205 2206 2207 2208 2209 |
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2202 class IoTJobAbortCriteria < Struct.new( :failure_type, :action, :threshold_percentage, :min_number_of_executed_things) SENSITIVE = [] include Aws::Structure end |