Class: Aws::GreengrassV2::Types::IoTJobExponentialRolloutRate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-greengrassv2/types.rb

Overview

Note:

When making an API call, you may pass IoTJobExponentialRolloutRate data as a hash:

{
  base_rate_per_minute: 1, # required
  increment_factor: 1.0, # required
  rate_increase_criteria: { # required
    number_of_notified_things: 1,
    number_of_succeeded_things: 1,
  },
}

Contains information about an exponential rollout rate for a configuration deployment job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#base_rate_per_minuteInteger

The minimum number of devices that receive a pending job notification, per minute, when the job starts. This parameter defines the initial rollout rate of the job.

Returns:

  • (Integer)


2360
2361
2362
2363
2364
2365
2366
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2360

class IoTJobExponentialRolloutRate < Struct.new(
  :base_rate_per_minute,
  :increment_factor,
  :rate_increase_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#increment_factorFloat

The exponential factor to increase the rollout rate for the job.

This parameter supports up to one digit after the decimal (for example, you can specify `1.5`, but not `1.55`).

Returns:

  • (Float)


2360
2361
2362
2363
2364
2365
2366
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2360

class IoTJobExponentialRolloutRate < Struct.new(
  :base_rate_per_minute,
  :increment_factor,
  :rate_increase_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#rate_increase_criteriaTypes::IoTJobRateIncreaseCriteria

The criteria to increase the rollout rate for the job.



2360
2361
2362
2363
2364
2365
2366
# File 'lib/aws-sdk-greengrassv2/types.rb', line 2360

class IoTJobExponentialRolloutRate < Struct.new(
  :base_rate_per_minute,
  :increment_factor,
  :rate_increase_criteria)
  SENSITIVE = []
  include Aws::Structure
end